@@ -46,6 +46,7 @@ Fixture::Fixture(QObject* parent) : QObject(parent)
 
     m_address = 0;
     m_channels = 0;
+    m_crossUniverse = false;
 
     m_fixtureDef = NULL;
     m_fixtureMode = NULL;
@@ -136,6 +137,16 @@ quint32 Fixture::universe() const
     return (m_address >> 9);
 }
 
+void Fixture::setCrossUniverse(bool enable)
+{
+    m_crossUniverse = enable;
+}
+
+bool Fixture::crossUniverse() const
+{
+    return m_crossUniverse;
+}
+
 /*****************************************************************************
  * Address
  *****************************************************************************/
@@ -310,7 +321,7 @@ QVector <quint32> Fixture::cmyChannels(int head) const
     return m_fixtureMode->heads().at(head).cmyChannels();
 }
 
-QList<SceneValue> Fixture::positionToValues(int type, int degrees, bool isRelative)
+QList<SceneValue> Fixture::positionToValues(int type, float degrees, bool isRelative)
 {
     QList<SceneValue> posList;
     // cache a list of channels processed, to avoid duplicates
@@ -415,8 +426,8 @@ QList<SceneValue> Fixture::zoomToValues(float degrees, bool isRelative)
 
     float deltaDegrees = phy.lensDegreesMax() - phy.lensDegreesMin();
     // delta : 0xFFFF = deg : x
-    quint16 degToDmx = ((degrees - (isRelative ? 0 : float(phy.lensDegreesMin()))) * 65535.0) / deltaDegrees;
-    //qDebug() << "Degrees" << degrees << "DMX" << QString::number(degToDmx, 16);
+    quint16 degToDmx = ((qAbs(degrees) - (isRelative ? 0 : float(phy.lensDegreesMin()))) * 65535.0) / deltaDegrees;
+    qDebug() << "Degrees" << degrees << "DMX" << QString::number(degToDmx, 16);
 
     for (quint32 i = 0; i < quint32(m_fixtureMode->channels().size()); i++)
     {
@@ -435,12 +446,16 @@ QList<SceneValue> Fixture::zoomToValues(float degrees, bool isRelative)
             // degrees is a relative value upon the current value.
             // Recalculate absolute degrees here
             qreal divider = ch->controlByte() == QLCChannel::MSB ? 256.0 : 65536.0;
-            float chDegrees = float((phy.lensDegreesMax() - phy.lensDegreesMin()) / divider) * float(channelValueAt(i));
+            uchar currDmxValue = ch->preset() == QLCChannel::BeamZoomBigSmall ? UCHAR_MAX - channelValueAt(i) : channelValueAt(i);
+            float chDegrees = float((phy.lensDegreesMax() - phy.lensDegreesMin()) / divider) * float(currDmxValue);
 
-            //qDebug() << "Relative channel degrees:" << chDegrees << "MSB?" << ch->controlByte();
+            qDebug() << "Relative channel degrees:" << chDegrees << "MSB?" << ch->controlByte();
 
             quint16 currDmxVal = (chDegrees * 65535.0) / deltaDegrees;
-            degToDmx += currDmxVal;
+            if (degrees > 0)
+                degToDmx = qBound(0, currDmxVal + degToDmx, 65535);
+            else
+                degToDmx = qBound(0, currDmxVal - degToDmx, 65535);
         }
 
         if (ch->controlByte() == QLCChannel::MSB)
@@ -833,126 +848,231 @@ QLCFixtureMode *Fixture::genericDimmerMode(QLCFixtureDef *def, int channels)
  * Generic RGB panel
  *********************************************************************/
 
-QLCFixtureDef *Fixture::genericRGBPanelDef(int columns, Components components)
+QString Fixture::componentsToString(Components comp, bool is16bit)
+{
+    QString compStr;
+
+    switch (comp)
+    {
+        case BGR:
+            compStr = "BGR";
+        break;
+        case BRG:
+            compStr = "BRG";
+        break;
+        case GBR:
+            compStr = "GBR";
+        break;
+        case GRB:
+            compStr = "GRB";
+        break;
+        case RBG:
+            compStr = "RBG";
+        break;
+        case RGBW:
+            compStr = "RGBW";
+        break;
+        default:
+            compStr = "RGB";
+        break;
+    }
+
+    if (is16bit)
+        compStr += " 16bit";
+
+    return compStr;
+}
+
+Fixture::Components Fixture::stringToComponents(QString str, bool &is16bit)
+{
+    QStringList strToken = str.split(' ');
+    is16bit = false;
+
+    if (strToken.count() == 2)
+    {
+        if (strToken.at(1) == "16bit")
+            is16bit = true;
+    }
+
+    if (strToken.at(0) == "BGR") return BGR;
+    else if (strToken.at(0) == "BRG") return BRG;
+    else if (strToken.at(0) == "GBR") return GBR;
+    else if (strToken.at(0) == "GRB") return GRB;
+    else if (strToken.at(0) == "RBG") return RBG;
+    else if (strToken.at(0) == "RGBW") return RGBW;
+    else return RGB;
+}
+
+QLCFixtureDef *Fixture::genericRGBPanelDef(int columns, Components components, bool is16bit)
 {
     QLCFixtureDef *def = new QLCFixtureDef();
     def->setManufacturer(KXMLFixtureGeneric);
     def->setModel(KXMLFixtureRGBPanel);
     def->setType(QLCFixtureDef::LEDBarPixels);
     def->setAuthor("QLC+");
+
     for (int i = 0; i < columns; i++)
     {
-        QLCChannel* red = new QLCChannel();
+        QLCChannel *red = new QLCChannel();
         red->setName(QString("Red %1").arg(i + 1));
         red->setGroup(QLCChannel::Intensity);
         red->setColour(QLCChannel::Red);
 
-        QLCChannel* green = new QLCChannel();
+        QLCChannel *green = new QLCChannel();
         green->setName(QString("Green %1").arg(i + 1));
         green->setGroup(QLCChannel::Intensity);
         green->setColour(QLCChannel::Green);
 
-        QLCChannel* blue = new QLCChannel();
+        QLCChannel *blue = new QLCChannel();
         blue->setName(QString("Blue %1").arg(i + 1));
         blue->setGroup(QLCChannel::Intensity);
         blue->setColour(QLCChannel::Blue);
 
+        QLCChannel *redFine = NULL;
+        QLCChannel *greenFine = NULL;
+        QLCChannel *blueFine = NULL;
+
+        if (is16bit)
+        {
+            redFine = new QLCChannel();
+            redFine->setName(QString("Red Fine %1").arg(i + 1));
+            redFine->setGroup(QLCChannel::Intensity);
+            redFine->setColour(QLCChannel::Red);
+            redFine->setControlByte(QLCChannel::LSB);
+
+            greenFine = new QLCChannel();
+            greenFine->setName(QString("Green Fine %1").arg(i + 1));
+            greenFine->setGroup(QLCChannel::Intensity);
+            greenFine->setColour(QLCChannel::Green);
+            greenFine->setControlByte(QLCChannel::LSB);
+
+            blueFine = new QLCChannel();
+            blueFine->setName(QString("Blue Fine %1").arg(i + 1));
+            blueFine->setGroup(QLCChannel::Intensity);
+            blueFine->setColour(QLCChannel::Blue);
+            blueFine->setControlByte(QLCChannel::LSB);
+        }
+
         if (components == BGR)
         {
             def->addChannel(blue);
+            if (is16bit) def->addChannel(blueFine);
             def->addChannel(green);
+            if (is16bit) def->addChannel(greenFine);
             def->addChannel(red);
+            if (is16bit) def->addChannel(redFine);
         }
         else if (components == BRG)
         {
             def->addChannel(blue);
+            if (is16bit) def->addChannel(blueFine);
             def->addChannel(red);
+            if (is16bit) def->addChannel(redFine);
             def->addChannel(green);
+            if (is16bit) def->addChannel(greenFine);
         }
         else if (components == GBR)
         {
             def->addChannel(green);
+            if (is16bit) def->addChannel(greenFine);
             def->addChannel(blue);
+            if (is16bit) def->addChannel(blueFine);
             def->addChannel(red);
+            if (is16bit) def->addChannel(redFine);
         }
         else if (components == GRB)
         {
             def->addChannel(green);
+            if (is16bit) def->addChannel(greenFine);
             def->addChannel(red);
+            if (is16bit) def->addChannel(redFine);
             def->addChannel(blue);
+            if (is16bit) def->addChannel(blueFine);
         }
         else if (components == RBG)
         {
             def->addChannel(red);
+            if (is16bit) def->addChannel(redFine);
             def->addChannel(blue);
+            if (is16bit) def->addChannel(blueFine);
             def->addChannel(green);
+            if (is16bit) def->addChannel(greenFine);
         }
         else if (components == RGBW)
         {
-            QLCChannel* white = new QLCChannel();
+            QLCChannel *white = new QLCChannel();
             white->setName(QString("White %1").arg(i + 1));
             white->setGroup(QLCChannel::Intensity);
             white->setColour(QLCChannel::White);
 
             def->addChannel(red);
+            if (is16bit) def->addChannel(redFine);
             def->addChannel(green);
+            if (is16bit) def->addChannel(greenFine);
             def->addChannel(blue);
+            if (is16bit) def->addChannel(blueFine);
             def->addChannel(white);
+
+            if (is16bit)
+            {
+                QLCChannel *whiteFine = new QLCChannel();
+                whiteFine->setName(QString("White Fine %1").arg(i + 1));
+                whiteFine->setGroup(QLCChannel::Intensity);
+                whiteFine->setColour(QLCChannel::White);
+                whiteFine->setControlByte(QLCChannel::LSB);
+                def->addChannel(whiteFine);
+            }
         }
         else
         {
             def->addChannel(red);
+            if (is16bit) def->addChannel(redFine);
             def->addChannel(green);
+            if (is16bit) def->addChannel(greenFine);
             def->addChannel(blue);
+            if (is16bit) def->addChannel(blueFine);
         }
     }
 
     return def;
 }
 
-QLCFixtureMode *Fixture::genericRGBPanelMode(QLCFixtureDef *def, Components components, quint32 width, quint32 height)
+QLCFixtureMode *Fixture::genericRGBPanelMode(QLCFixtureDef *def, Components components, bool is16bit,
+                                             quint32 width, quint32 height)
 {
     Q_ASSERT(def != NULL);
+
     QLCFixtureMode *mode = new QLCFixtureMode(def);
-    int compNum = 3;
-    if (components == BGR)
-        mode->setName("BGR");
-    else if (components == BRG)
-        mode->setName("BRG");
-    else if (components == GBR)
-        mode->setName("GBR");
-    else if (components == GRB)
-        mode->setName("GRB");
-    else if (components == RBG)
-        mode->setName("RBG");
-    else if (components == RGBW)
-    {
-        mode->setName("RGBW");
-        compNum = 4;
-    }
-    else
-        mode->setName("RGB");
+    QString modeName = componentsToString(components, is16bit);
+    mode->setName(modeName);
+
+    int compNum = components == RGBW ? 4 : 3;
+    if (is16bit)
+        compNum *= 2;
 
     QList<QLCChannel *>channels = def->channels();
-    for (int i = 0; i < channels.count(); i++)
+    int i = 0;
+
+    // add channels and heads
+    for (int h = 0; h < channels.count() / compNum; h++)
     {
-        QLCChannel *ch = channels.at(i);
-        mode->insertChannel(ch, i);
-        if (i%compNum == 0)
+        QLCFixtureHead head;
+
+        for (int c = 0; c < compNum; c++, i++)
         {
-            QLCFixtureHead head;
+            QLCChannel *ch = channels.at(i);
+            mode->insertChannel(ch, i);
             head.addChannel(i);
-            head.addChannel(i+1);
-            head.addChannel(i+2);
-            if (components == RGBW)
-                head.addChannel(i+3);
-            mode->insertHead(-1, head);
         }
+
+        mode->insertHead(-1, head);
     }
+
     QLCPhysical physical;
     physical.setWidth(width);
     physical.setHeight(height);
     physical.setDepth(height);
+    physical.setLayoutSize(QSize(mode->heads().count(), 1));
 
     mode->setPhysical(physical);
     def->addMode(mode);
@@ -973,7 +1093,7 @@ bool Fixture::loader(QXmlStreamReader &root, Doc* doc)
 
     if (fxi->loadXML(root, doc, doc->fixtureDefCache()) == true)
     {
-        if (doc->addFixture(fxi, fxi->id()) == true)
+        if (doc->addFixture(fxi, fxi->id(), fxi->crossUniverse()) == true)
         {
             /* Success */
             result = true;
@@ -1035,7 +1155,7 @@ bool Fixture::loadXML(QXmlStreamReader &xmlDoc, Doc *doc,
         {
             modeName = xmlDoc.readElementText();
         }
-        else if (xmlDoc.name() == KXMLQLCPhysicalDimensionsWeight)
+        else if (xmlDoc.name() == KXMLQLCPhysicalDimensionsWidth)
         {
             width = xmlDoc.readElementText().toUInt();
         }
@@ -1055,6 +1175,11 @@ bool Fixture::loadXML(QXmlStreamReader &xmlDoc, Doc *doc,
         {
             universe = xmlDoc.readElementText().toInt();
         }
+        else if (xmlDoc.name() == KXMLFixtureCrossUniverse)
+        {
+            xmlDoc.readElementText();
+            setCrossUniverse(true);
+        }
         else if (xmlDoc.name() == KXMLFixtureAddress)
         {
             address = xmlDoc.readElementText().toInt();
@@ -1156,14 +1281,14 @@ bool Fixture::loadXML(QXmlStreamReader &xmlDoc, Doc *doc,
     /* Number of channels */
     if (channels <= 0)
     {
-        doc->appendToErrorLog(QString("%1 channels of fixture <b>%2</b> are our of bounds")
+        doc->appendToErrorLog(QString("%1 channels of fixture <b>%2</b> are out of bounds")
                               .arg(QString::number(channels))
                               .arg(name));
         channels = 1;
     }
 
     /* Make sure that address is something sensible */
-    if (address > 511 || address + (channels - 1) > 511)
+    if (!crossUniverse() && (address > 511 || address + (channels - 1) > 511))
     {
         doc->appendToErrorLog(QString("Fixture address range %1-%2 is out of DMX bounds")
                               .arg(QString::number(address))
@@ -1185,21 +1310,14 @@ bool Fixture::loadXML(QXmlStreamReader &xmlDoc, Doc *doc,
     }
     else if (model == KXMLFixtureRGBPanel)
     {
-        Components components = RGB;
-        int compNum = 3;
-        if (modeName == "BGR") components = BGR;
-        else if (modeName == "BRG") components = BRG;
-        else if (modeName == "GBR") components = GBR;
-        else if (modeName == "GRB") components = GRB;
-        else if (modeName == "RBG") components = RBG;
-        else if (modeName == "RGBW")
-        {
-            components = RGBW;
-            compNum = 4;
-        }
+        bool is16bit = false;
+        Components components = stringToComponents(modeName, is16bit);
+        int compNum = components == RGBW ? 4 : 3;
+        if (is16bit)
+            compNum *= 2;
 
-        fixtureDef = genericRGBPanelDef(channels / compNum, components);
-        fixtureMode = genericRGBPanelMode(fixtureDef, components, width, height);
+        fixtureDef = genericRGBPanelDef(channels / compNum, components, is16bit);
+        fixtureMode = genericRGBPanelMode(fixtureDef, components, is16bit, width, height);
     }
 
     if (fixtureDef != NULL && fixtureMode != NULL)
@@ -1254,7 +1372,7 @@ bool Fixture::saveXML(QXmlStreamWriter *doc) const
     /* RGB Panel physical dimensions */
     if (m_fixtureDef != NULL && m_fixtureDef->model() == KXMLFixtureRGBPanel && m_fixtureMode != NULL)
     {
-        doc->writeTextElement(KXMLQLCPhysicalDimensionsWeight,
+        doc->writeTextElement(KXMLQLCPhysicalDimensionsWidth,
                               QString::number(m_fixtureMode->physical().width()));
 
         doc->writeTextElement(KXMLQLCPhysicalDimensionsHeight,
@@ -1267,6 +1385,8 @@ bool Fixture::saveXML(QXmlStreamWriter *doc) const
     doc->writeTextElement(KXMLFixtureName, m_name);
     /* Universe */
     doc->writeTextElement(KXMLFixtureUniverse, QString::number(universe()));
+    if (crossUniverse())
+        doc->writeTextElement(KXMLFixtureCrossUniverse, KXMLQLCTrue);
     /* Address */
     doc->writeTextElement(KXMLFixtureAddress, QString::number(address()));
     /* Channel count */
