@@ -26,6 +26,7 @@
 #include <math.h>
 
 #include "qlcmacros.h"
+#include "qlcfile.h"
 
 #include "scriptwrapper.h"
 #include "mastertimer.h"
@@ -334,7 +335,7 @@ bool Function::saveXMLCommon(QXmlStreamWriter *doc) const
     doc->writeAttribute(KXMLQLCFunctionType, Function::typeToString(type()));
     doc->writeAttribute(KXMLQLCFunctionName, name());
     if (isVisible() == false)
-        doc->writeAttribute(KXMLQLCFunctionHidden, "True");
+        doc->writeAttribute(KXMLQLCFunctionHidden, KXMLQLCTrue);
     if (path(true).isEmpty() == false)
         doc->writeAttribute(KXMLQLCFunctionPath, path(true));
     if (blendMode() != Universe::NormalBlend)
