@@ -32,7 +32,7 @@ QList<SceneValue> KeyPadParser::parseCommand(Doc *doc, QString command,
                                              QByteArray &uniData)
 {
     QList<SceneValue> values;
-    if (doc == NULL)
+    if (doc == NULL || command.isEmpty())
         return values;
 
     QStringList tokens = command.split(" ");
@@ -61,16 +61,12 @@ QList<SceneValue> KeyPadParser::parseCommand(Doc *doc, QString command,
         }
         else if (token == "FULL")
         {
-            if (lastCommand == CommandAT)
-                toValue = 255;
-
+            toValue = 255;
             lastCommand = CommandFULL;
         }
         else if (token == "ZERO")
         {
-            if (lastCommand == CommandAT)
-                toValue = 0;
-
+            toValue = 0;
             lastCommand = CommandZERO;
         }
         else if (token == "BY")
@@ -89,7 +85,6 @@ QList<SceneValue> KeyPadParser::parseCommand(Doc *doc, QString command,
         {
             lastCommand = CommandPlusPercent;
         }
-
         else if (token == "-%")
         {
             lastCommand = CommandMinusPercent;
@@ -119,6 +114,8 @@ QList<SceneValue> KeyPadParser::parseCommand(Doc *doc, QString command,
 
                     fromChannel = number;
                     toChannel = fromChannel;
+                    fromValue = uchar(uniData.at(number - 1));
+                    toValue = fromValue;
                     channelSet = true;
                 break;
                 case CommandAT:
