@@ -22,6 +22,7 @@
 
 #include <QStringList>
 #include <QVariant>
+#include <QObject>
 #include <QString>
 #include <QHash>
 #include <QMap>
@@ -39,9 +40,15 @@ class QXmlStreamReader;
 #define KXMLQLCInputProfileModel            QString("Model")
 #define KXMLQLCInputProfileType             QString("Type")
 #define KXMLQLCInputProfileMidiSendNoteOff  QString("MIDISendNoteOff")
+#define KXMLQLCInputProfileColorTable       QString("ColorTable")
+#define KXMLQLCInputProfileColor            QString("Color")
+#define KXMLQLCInputProfileMidiChannelTable QString("MidiChannelTable")
+#define KXMLQLCInputProfileMidiChannel      QString("Channel")
 
-class QLCInputProfile
+class QLCInputProfile : public QObject
 {
+    Q_OBJECT
+
     /********************************************************************
      * Initialization
      ********************************************************************/
@@ -49,12 +56,11 @@ public:
     /** Standard constructor */
     QLCInputProfile();
 
-    /** Copy constructor */
-    QLCInputProfile(const QLCInputProfile& profile);
-
     /** Destructor */
     virtual ~QLCInputProfile();
 
+    QLCInputProfile *createCopy();
+
     /** Assignment operator */
     QLCInputProfile& operator=(const QLCInputProfile& profile);
 
@@ -73,17 +79,21 @@ public:
 
     /** Get the path where the profile is stored in. Don't use
         this as a unique ID since this varies between platforms. */
+    void setPath(QString path);
     QString path() const;
 
     enum Type
     {
-        MIDI,
+        MIDI = 0,
         OS2L,
         OSC,
         HID,
         DMX,
         Enttec,
     };
+#if QT_VERSION >= 0x050500
+    Q_ENUM(Type)
+#endif
 
     void setType(Type type);
 
@@ -159,7 +169,7 @@ public:
      * @param channel The number of the channel to get.
      * @return A QLCInputChannel* or NULL if not found.
      */
-    QLCInputChannel* channel(quint32 channel) const;
+    QLCInputChannel *channel(quint32 channel) const;
 
     /**
      * Get the channel number for the given input channel.
@@ -174,6 +184,12 @@ public:
      */
     QMap <quint32,QLCInputChannel*> channels() const;
 
+    /**
+     *  Retrieve additional parameters to be passed to plugins
+     *  when sending feedback.
+     */
+    QVariant channelExtraParams(const QLCInputChannel *channel) const;
+
 private:
     /** Delete and remove all channels */
     void destroyChannels();
@@ -183,6 +199,32 @@ protected:
         QList because not all channels might be present. */
     QMap <quint32, QLCInputChannel*> m_channels;
 
+    /********************************************************************
+     * Color Translation Table
+     ********************************************************************/
+public:
+    bool hasColorTable();
+    void addColor(uchar value, QString label, QColor color);
+    void removeColor(uchar value);
+
+    QMap<uchar, QPair<QString, QColor>> colorTable();
+
+protected:
+    QMap<uchar, QPair<QString, QColor>> m_colorTable;
+
+    /********************************************************************
+     * MIDI Channel table
+     ********************************************************************/
+public:
+    bool hasMidiChannelTable();
+    void addMidiChannel(uchar channel, QString label);
+    void removeMidiChannel(uchar channel);
+
+    QMap<uchar, QString> midiChannelTable();
+
+protected:
+    QMap<uchar, QString> m_midiChannelTable;
+
     /********************************************************************
      * Load & Save
      ********************************************************************/
@@ -193,6 +235,12 @@ public:
     /** Save an input profile into a given file name */
     bool saveXML(const QString& fileName);
 
+    /** Load an optional color table for RGB LED feedback */
+    bool loadColorTableXML(QXmlStreamReader &tableRoot);
+
+    /** Load an optional MIDI channel table */
+    bool loadMidiChannelTableXML(QXmlStreamReader &tableRoot);
+
     /** Load an input profile from the given document */
     bool loadXML(QXmlStreamReader &doc);
 };
