@@ -164,11 +164,15 @@ public:
 
     enum FanningLayout
     {
-        LeftToRight,
-        RightToLeft,
-        TopToBottom,
-        BottomToTop,
-        Centered
+        XAscending,
+        XDescending,
+        XCentered,
+        YAscending,
+        YDescending,
+        YCentered,
+        ZAscending,
+        ZDescending,
+        ZCentered
     };
 #if QT_VERSION >= 0x050500
     Q_ENUM(FanningLayout)
