@@ -108,6 +108,12 @@ bool RGBImage::animatedSource() const
     return m_animatedSource;
 }
 
+void RGBImage::rewindAnimation()
+{
+    if (m_animatedSource)
+        m_animatedPlayer.jumpToFrame(0);
+}
+
 void RGBImage::reloadImage()
 {
     m_animatedSource = false;
@@ -235,6 +241,16 @@ int RGBImage::rgbMapStepCount(const QSize& size)
     }
 }
 
+void RGBImage::rgbMapSetColors(QVector<uint> &colors)
+{
+    Q_UNUSED(colors);
+}
+
+QVector<uint> RGBImage::rgbMapGetColors()
+{
+    return QVector<uint>();
+}
+
 void RGBImage::rgbMap(const QSize& size, uint rgb, int step, RGBMap &map)
 {
     Q_UNUSED(rgb);
