@@ -59,11 +59,14 @@ public:
     void setImageData(int width, int height, const QByteArray& pixelData);
 
     bool animatedSource() const;
+    void rewindAnimation();
 
 private:
-
     void reloadImage();
 
+protected slots:
+    void frameChanged(int num);
+
 private:
     QString m_filename;
     bool m_animatedSource;
@@ -102,6 +105,12 @@ public:
     /** @reimp */
     int rgbMapStepCount(const QSize& size);
 
+    /** @reimp */
+    void rgbMapSetColors(QVector<uint> &colors);
+
+    /** @reimp */
+    QVector<uint> rgbMapGetColors();
+
     /** @reimp */
     void rgbMap(const QSize& size, uint rgb, int step, RGBMap &map);
 
