@@ -49,6 +49,12 @@ public:
     /** @reimp */
     int rgbMapStepCount(const QSize& size);
 
+    /** @reimp */
+    void rgbMapSetColors(QVector<uint> &colors);
+
+    /** @reimp */
+    QVector<uint> rgbMapGetColors();
+
     /** @reimp */
     void rgbMap(const QSize& size, uint rgb, int step, RGBMap &map);
 
@@ -62,7 +68,7 @@ public:
     int apiVersion() const;
 
     /** @reimp */
-    void setColors(QColor start, QColor end);
+    void setColors(QVector<QColor> colors);
 
     /** @reimp */
     RGBAlgorithm::Type type() const;
