@@ -98,6 +98,12 @@ public:
     /** @reimp */
     int rgbMapStepCount(const QSize& size);
 
+    /** @reimp */
+    void rgbMapSetColors(QVector<uint> &colors);
+
+    /** @reimp */
+    QVector<uint> rgbMapGetColors();
+
     /** @reimp */
     void rgbMap(const QSize& size, uint rgb, int step, RGBMap &map);
 
