@@ -38,7 +38,9 @@ ScriptRunner::ScriptRunner(Doc *doc, QString &content, QObject *parent)
     , m_content(content)
     , m_running(false)
     , m_engine(NULL)
+    , m_stopOnExit(true)
     , m_waitCount(0)
+    , m_waitFunctionId(Function::invalidId())
 {
 }
 
@@ -170,13 +172,14 @@ bool ScriptRunner::write(MasterTimer *timer, QList<Universe *> universes)
             fc->setReady(false);
         }
     }
-    if (m_functionQueue.count())
+    // if we don't have to wait and there are some funtions in the queue
+    if (m_waitFunctionId == Function::invalidId() && m_functionQueue.count())
     {
         while (!m_functionQueue.isEmpty())
         {
-            QPair<quint32,bool> pair = m_functionQueue.dequeue();
+            QPair<quint32, FunctionOperation> &pair = m_functionQueue.head();
             quint32 fID = pair.first;
-            bool start = pair.second;
+            FunctionOperation operation = pair.second;
 
             Function *function = m_doc->function(fID);
             if (function == NULL)
@@ -185,16 +188,39 @@ bool ScriptRunner::write(MasterTimer *timer, QList<Universe *> universes)
                 continue;
             }
 
-            if (start)
+            if (operation == FunctionOperation::START || operation == FunctionOperation::START_DONT_STOP)
             {
                 function->start(timer, FunctionParent::master());
-                m_startedFunctions << fID;
+                if (operation == FunctionOperation::START)
+                    m_startedFunctions << fID;
             }
-            else
+            else if (operation == FunctionOperation::STOP)
             {
                 function->stop(FunctionParent::master());
                 m_startedFunctions.removeAll(fID);
             }
+            else if (operation == FunctionOperation::WAIT_START)
+            {
+                if (!function->isRunning())
+                {
+                    // the function is not running, so we we wait and we stop dequeuing
+                    m_waitFunctionId = fID;
+                    connect(m_doc->masterTimer(), SIGNAL(functionStarted(quint32)), SLOT(slotWaitFunctionStarted(quint32)));
+                    break;
+                }
+            }
+            else if (operation == FunctionOperation::WAIT_STOP)
+            {
+                if (!function->stopped())
+                {
+                    // the function has to start or is still running, so we wait and we stop dequeuing
+                    m_waitFunctionId = fID;
+                    connect(m_doc->masterTimer(), SIGNAL(functionStopped(quint32)), SLOT(slotWaitFunctionStopped(quint32)));
+                    break;
+                }
+            }
+            // we can continue with the next function in the queue
+            m_functionQueue.removeFirst();
         }
     }
 
@@ -206,6 +232,25 @@ bool ScriptRunner::write(MasterTimer *timer, QList<Universe *> universes)
     return true;
 }
 
+void ScriptRunner::slotWaitFunctionStarted(quint32 fid)
+{
+    if (m_waitFunctionId == fid)
+    {
+        disconnect(m_doc->masterTimer(), SIGNAL(functionStarted(quint32)), this, SLOT(slotWaitFunctionStarted(quint32)));
+        m_waitFunctionId = Function::invalidId();
+    }
+}
+
+void ScriptRunner::slotWaitFunctionStopped(quint32 fid)
+{
+    if (m_waitFunctionId == fid)
+    {
+        disconnect(m_doc->masterTimer(), SIGNAL(functionStopped(quint32)), this, SLOT(slotWaitFunctionStopped(quint32)));
+        m_startedFunctions.removeAll(fid);
+        m_waitFunctionId = Function::invalidId();
+    }
+}
+
 void ScriptRunner::run()
 {
     m_waitCount = 0;
@@ -301,89 +346,70 @@ bool ScriptRunner::setFixture(quint32 fxID, quint32 channel, uchar value, uint t
     return true;
 }
 
-bool ScriptRunner::startFunction(quint32 fID)
+bool ScriptRunner::stopOnExit(bool value)
+{
+    m_stopOnExit = value;
+
+    return true;
+}
+
+Function* ScriptRunner::getFunctionIfRunning(quint32 fID)
 {
     if (m_running == false)
-        return false;
+        return NULL;
 
     Function *function = m_doc->function(fID);
     if (function == NULL)
     {
         qWarning() << QString("No such function (ID %1)").arg(fID);
-        return false;
+        return NULL;
     }
 
-    QPair<quint32,bool> pair;
+    return function;
+}
+
+bool ScriptRunner::enqueueFunction(quint32 fID, FunctionOperation operation)
+{
+    Function *function = getFunctionIfRunning(fID);
+    if (function == NULL)
+        return false;
+
+    QPair<quint32, FunctionOperation> pair;
     pair.first = fID;
-    pair.second = true;
+    pair.second = operation;
 
     m_functionQueue.enqueue(pair);
 
     return true;
 }
 
+bool ScriptRunner::startFunction(quint32 fID)
+{
+    return enqueueFunction(fID, m_stopOnExit ? FunctionOperation::START : FunctionOperation::START_DONT_STOP);
+}
+
 bool ScriptRunner::stopFunction(quint32 fID)
 {
-    if (m_running == false)
-        return false;
-
-    Function *function = m_doc->function(fID);
-    if (function == NULL)
-    {
-        qWarning() << QString("No such function (ID %1)").arg(fID);
-        return false;
-    }
-
-    QPair<quint32,bool> pair;
-    pair.first = fID;
-    pair.second = false;
-
-    m_functionQueue.enqueue(pair);
-
-    return true;
+    return enqueueFunction(fID, FunctionOperation::STOP);
 }
 
 bool ScriptRunner::isFunctionRunning(quint32 fID)
 {
-    if (m_running == false)
-        return false;
-
-    Function *function = m_doc->function(fID);
-    if (function == NULL)
-    {
-        qWarning() << QString("No such function (ID %1)").arg(fID);
-        return false;
-    }
-
-    return function->isRunning();
+    Function *function = getFunctionIfRunning(fID);
+    return function == NULL ? false : function->isRunning();
 }
 
 float ScriptRunner::getFunctionAttribute(quint32 fID, int attributeIndex)
 {
-    if (m_running == false)
-        return false;
-
-    Function *function = m_doc->function(fID);
-    if (function == NULL)
-    {
-        qWarning() << QString("No such function (ID %1)").arg(fID);
-        return 0;
-    }
-
-    return function->getAttributeValue(attributeIndex);
+    Function *function = getFunctionIfRunning(fID);
+    return function == NULL ? 0 : function->getAttributeValue(attributeIndex);
 }
 
 bool ScriptRunner::setFunctionAttribute(quint32 fID, int attributeIndex, float value)
 {
-    if (m_running == false)
-        return false;
-
-    Function *function = m_doc->function(fID);
+    Function *function = getFunctionIfRunning(fID);
     if (function == NULL)
-    {
-        qWarning() << QString("No such function (ID %1)").arg(fID);
         return false;
-    }
 
     function->adjustAttribute(value, attributeIndex);
 
@@ -392,15 +418,9 @@ bool ScriptRunner::setFunctionAttribute(quint32 fID, int attributeIndex, float v
 
 bool ScriptRunner::setFunctionAttribute(quint32 fID, QString attributeName, float value)
 {
-    if (m_running == false)
-        return false;
-
-    Function *function = m_doc->function(fID);
+    Function *function = getFunctionIfRunning(fID);
     if (function == NULL)
-    {
-        qWarning() << QString("No such function (ID %1)").arg(fID);
         return false;
-    }
 
     int attrIndex = function->getAttributeIndex(attributeName);
     function->adjustAttribute(value, attrIndex);
@@ -504,6 +524,16 @@ bool ScriptRunner::waitTime(QString time)
     return true;
 }
 
+bool ScriptRunner::waitFunctionStart(quint32 fID)
+{
+    return enqueueFunction(fID, FunctionOperation::WAIT_START);
+}
+
+bool ScriptRunner::waitFunctionStop(quint32 fID)
+{
+    return enqueueFunction(fID, FunctionOperation::WAIT_STOP);
+}
+
 bool ScriptRunner::setBlackout(bool enable)
 {
     if (m_running == false)
