@@ -229,7 +229,7 @@ bool Show::addTrack(Track *track, quint32 id)
      track->setShowId(this->id());
      m_tracks[id] = track;
 
-     registerAttribute(track->name());
+     registerAttribute(QString("%1-%2").arg(track->name()).arg(track->id()));
 
      return true;
 }
@@ -238,13 +238,13 @@ bool Show::removeTrack(quint32 id)
 {
     if (m_tracks.contains(id) == true)
     {
-        Track* trk = m_tracks.take(id);
-        Q_ASSERT(trk != NULL);
+        Track* track = m_tracks.take(id);
+        Q_ASSERT(track != NULL);
 
-        unregisterAttribute(trk->name());
+        unregisterAttribute(QString("%1-%2").arg(track->name()).arg(track->id()));
 
         //emit trackRemoved(id);
-        delete trk;
+        delete track;
 
         return true;
     }
