@@ -32,12 +32,15 @@ class Doc;
  */
 
 #define KXMLShowFunction QString("ShowFunction")
+#define KXMLShowFunctionUid QString("UID")
+#define KXMLShowFunctionTrackId QString("TrackID")
 
 class ShowFunction: public QObject
 {
     Q_OBJECT
     Q_DISABLE_COPY(ShowFunction)
 
+    Q_PROPERTY(int id READ id CONSTANT)
     Q_PROPERTY(int functionID READ functionID WRITE setFunctionID NOTIFY functionIDChanged)
     Q_PROPERTY(int startTime READ startTime WRITE setStartTime NOTIFY startTimeChanged)
     Q_PROPERTY(int duration READ duration WRITE setDuration NOTIFY durationChanged)
@@ -45,9 +48,12 @@ class ShowFunction: public QObject
     Q_PROPERTY(bool locked READ isLocked WRITE setLocked NOTIFY lockedChanged)
 
 public:
-    ShowFunction(QObject *parent = 0);
+    ShowFunction(quint32 id, QObject *parent = 0);
     virtual ~ShowFunction() {}
 
+    /** Get the ShowFunction unique identifier in a Show */
+    quint32 id() const;
+
     /** Get/Set the Function ID this class represents */
     void setFunctionID(quint32 id);
     quint32 functionID() const;
@@ -85,9 +91,12 @@ signals:
     void lockedChanged();
 
 private:
-    /** ID of the QLC+ Function this class represents */
+    /** ID of this class to uniquely identify it within a Show */
     quint32 m_id;
 
+    /** ID of the QLC+ Function this class represents */
+    quint32 m_functionId;
+
     /** Start time of the Function in milliseconds */
     quint32 m_startTime;
 
@@ -112,7 +121,7 @@ public:
     bool loadXML(QXmlStreamReader &root);
 
     /** Save ShowFunction contents to $doc */
-    bool saveXML(QXmlStreamWriter *doc) const;
+    bool saveXML(QXmlStreamWriter *doc, quint32 trackId = UINT_MAX) const;
 };
 
 /** @} */
