@@ -75,7 +75,7 @@ protected slots:
     void slotManufacturerTextEdited(const QString &text);
     void slotModelTextEdited(const QString &text);
     void slotAuthorTextEdited(const QString &text);
-    void slotTypeActivated(const QString &text);
+    void slotTypeActivated(int index);
 
 protected:
     bool checkManufacturerModel();
