@@ -74,7 +74,8 @@ bool DMXInterface::validInterface(quint16 vendor, quint16 product)
 {
     if (vendor != DMXInterface::FTDIVID &&
         vendor != DMXInterface::ATMELVID &&
-        vendor != DMXInterface::MICROCHIPVID)
+        vendor != DMXInterface::MICROCHIPVID &&
+        vendor != DMXInterface::NXPVID)
             return false;
 
     if (product != DMXInterface::FTDIPID &&
@@ -82,7 +83,8 @@ bool DMXInterface::validInterface(quint16 vendor, quint16 product)
         product != DMXInterface::DMX4ALLPID &&
         product != DMXInterface::NANODMXPID &&
         product != DMXInterface::EUROLITEPID &&
-        product != DMXInterface::ELECTROTASPID)
+        product != DMXInterface::ELECTROTASPID &&
+        product != DMXInterface::DMXKINGMAXPID)
             return false;
 
     return true;
