@@ -118,11 +118,11 @@ QString UDMX::outputInfo(quint32 output)
     return str;
 }
 
-void UDMX::writeUniverse(quint32 universe, quint32 output, const QByteArray &data)
+void UDMX::writeUniverse(quint32 universe, quint32 output, const QByteArray &data, bool dataChanged)
 {
     Q_UNUSED(universe)
 
-    if (output < quint32(m_devices.size()))
+    if (output < quint32(m_devices.size()) && dataChanged)
         m_devices.at(output)->outputDMX(data);
 }
 
