@@ -40,6 +40,8 @@ void ModelSelector::selectSingleItem(int index, ListModel *model)
     model->setDataWithRole(idx, "isSelected", true);
     m_selectedIndices.append(index);
     m_itemsCount++;
+
+    emit itemSelectionChanged(index, true);
 }
 
 void ModelSelector::selectItem(int index, ListModel *model, int keyModifiers)
@@ -78,6 +80,7 @@ void ModelSelector::resetSelection(ListModel *model)
     {
         QModelIndex idx = model->index(int(sidx), 0, QModelIndex());
         model->setDataWithRole(idx, "isSelected", false);
+        emit itemSelectionChanged(sidx, false);
     }
 
     m_selectedIndices.clear();
