@@ -24,9 +24,9 @@
 #include <QQuickItem>
 
 #include "previewcontext.h"
+#include "show.h"
 
 class Doc;
-class Show;
 class Track;
 class Function;
 class ShowFunction;
@@ -43,15 +43,21 @@ class ShowManager : public PreviewContext
     Q_OBJECT
 
     Q_PROPERTY(int currentShowID READ currentShowID WRITE setCurrentShowID NOTIFY currentShowIDChanged)
+    Q_PROPERTY(bool isEditing READ isEditing NOTIFY isEditingChanged)
     Q_PROPERTY(QString showName READ showName WRITE setShowName NOTIFY showNameChanged)
     Q_PROPERTY(QColor itemsColor READ itemsColor WRITE setItemsColor NOTIFY itemsColorChanged)
-    Q_PROPERTY(float timeScale READ timeScale WRITE setTimeScale NOTIFY timeScaleChanged)
-    Q_PROPERTY(float tickSize READ tickSize CONSTANT)
+
     Q_PROPERTY(bool stretchFunctions READ stretchFunctions WRITE setStretchFunctions NOTIFY stretchFunctionsChanged)
     Q_PROPERTY(bool gridEnabled READ gridEnabled WRITE setGridEnabled NOTIFY gridEnabledChanged)
-    Q_PROPERTY(int currentTime READ currentTime WRITE setCurrentTime NOTIFY currentTimeChanged)
     Q_PROPERTY(bool isPlaying READ isPlaying NOTIFY isPlayingChanged)
     Q_PROPERTY(int showDuration READ showDuration NOTIFY showDurationChanged)
+
+    Q_PROPERTY(Show::TimeDivision timeDivision READ timeDivision WRITE setTimeDivision NOTIFY timeDivisionChanged)
+    Q_PROPERTY(int beatsDivision READ beatsDivision NOTIFY beatsDivisionChanged)
+    Q_PROPERTY(float timeScale READ timeScale WRITE setTimeScale NOTIFY timeScaleChanged)
+    Q_PROPERTY(float tickSize READ tickSize NOTIFY tickSizeChanged)
+    Q_PROPERTY(int currentTime READ currentTime WRITE setCurrentTime NOTIFY currentTimeChanged)
+
     Q_PROPERTY(QVariant tracks READ tracks NOTIFY tracksChanged)
     Q_PROPERTY(int selectedTrackIndex READ selectedTrackIndex WRITE setSelectedTrackIndex NOTIFY selectedTrackIndexChanged)
     Q_PROPERTY(int selectedItemsCount READ selectedItemsCount NOTIFY selectedItemsCountChanged)
@@ -62,6 +68,12 @@ public:
     /** Return the ID of the Show Function being edited */
     int currentShowID() const;
 
+    /** Return a reference of the Show currently being edited */
+    Show *currentShow() const;
+
+    /** Flag to indicate if a Show is currently being edited */
+    bool isEditing();
+
     /** Set the ID of the Show Function to edit */
     void setCurrentShowID(int currentShowID);
 
@@ -85,13 +97,6 @@ public:
     /** Return the current Show total duration in milliseconds */
     int showDuration() const;
 
-    /** Get/Set the current time scale of the Show Manager timeline */
-    float timeScale() const;
-    void setTimeScale(float timeScale);
-
-    /** Get the size in pixels of the Show header time division */
-    float tickSize() const;
-
     /** Get/Set the Function stretch flag */
     bool stretchFunctions() const;
     void setStretchFunctions(bool stretchFunctions);
@@ -100,10 +105,6 @@ public:
     bool gridEnabled() const;
     void setGridEnabled(bool gridEnabled);
 
-    /** Get/Set the current time of the Show (aka cursor position) */
-    int currentTime() const;
-    void setCurrentTime(int currentTime);
-
     /** Play or resume the Show playback */
     Q_INVOKABLE void playShow();
 
@@ -115,11 +116,10 @@ public:
 
 signals:
     void currentShowIDChanged(int currentShowID);
+    void isEditingChanged();
     void showNameChanged(QString showName);
-    void timeScaleChanged(float timeScale);
     void stretchFunctionsChanged(bool stretchFunction);
     void gridEnabledChanged(bool gridEnabled);
-    void currentTimeChanged(int currentTime);
     void isPlayingChanged(bool playing);
     void showDurationChanged(int showDuration);
 
@@ -127,12 +127,6 @@ private:
     /** A reference to the Show Function being edited */
     Show *m_currentShow;
 
-    /** The current time scale of the Show Manager timeline */
-    float m_timeScale;
-
-    /** Size in pixels of the Show Manager time division */
-    float m_tickSize;
-
     /** Flag that indicates if a Function should be stretched
      *  when the corresponding Show Item duration changes */
     bool m_stretchFunctions;
@@ -141,6 +135,40 @@ private:
      *  snapped to the closest grid divisor */
     bool m_gridEnabled;
 
+    /*********************************************************************
+      * Time
+      ********************************************************************/
+public:
+    /** Get/Set the Show time division */
+    Show::TimeDivision timeDivision();
+    void setTimeDivision(Show::TimeDivision division);
+    int beatsDivision();
+
+    /** Get/Set the current time scale of the Show Manager timeline */
+    float timeScale() const;
+    void setTimeScale(float timeScale);
+
+    /** Get the size in pixels of the Show header time division */
+    float tickSize() const;
+
+    /** Get/Set the current time of the Show (aka cursor position) */
+    int currentTime() const;
+    void setCurrentTime(int currentTime);
+
+signals:
+    void timeDivisionChanged(Show::TimeDivision division);
+    void beatsDivisionChanged(int beatsDivision);
+    void timeScaleChanged(float timeScale);
+    void tickSizeChanged(float tickSize);
+    void currentTimeChanged(int currentTime);
+
+private:
+    /** The current time scale of the Show Manager timeline */
+    float m_timeScale;
+
+    /** Size in pixels of the Show Manager time division */
+    float m_tickSize;
+
     /** The current time position of the Show in ms */
     int m_currentTime;
 
@@ -199,12 +227,19 @@ public:
     /** Add a new Item to the timeline.
      *  This happens when dragging an existing Function from the Function Manager.
      *  If the current Show is NULL, a new Show is created.
-     *  If the provided $trackIdx is no valid, a new Track is created
+     *  If the provided $trackIdx is not valid, a new Track is created
      */
     Q_INVOKABLE void addItems(QQuickItem *parent, int trackIdx, int startTime, QVariantList idsList);
 
+    /** Add a Show item from an existing ShowFunction reference and Track Id */
+    void addShowItem(ShowFunction *sf, quint32 trackId);
+
+    /** Delete the currently selected show items */
     Q_INVOKABLE void deleteShowItems(QVariantList data);
 
+    /** Delete the item referencing the provided ShowFunction from the QML view */
+    void deleteShowItem(ShowFunction *sf);
+
     /** Method invoked when moving an existing Show Item on the timeline.
      *  The new position is checked for overlapping against existing items on the
      *  provided $newTrackIdx. On overlapping, false is returned and the UI
@@ -215,6 +250,12 @@ public:
     Q_INVOKABLE bool checkAndMoveItem(ShowFunction *sf,  int originalTrackIdx,
                                       int newTrackIdx, int newStartTime);
 
+    /** Set the start time of a ShowFunction item (if not overlapping) */
+    Q_INVOKABLE bool setShowItemStartTime(ShowFunction *sf, int startTime);
+
+    /** Set the duration of a ShowFunction item (if not overlapping) */
+    Q_INVOKABLE bool setShowItemDuration(ShowFunction *sf, int duration);
+
     /** Returns the number of the currently selected Show items */
     int selectedItemsCount() const;
 
