@@ -413,7 +413,7 @@ void SimpleDesk::dumpDmxChannels(QString name, quint32 mask)
 {
     QList<quint32> fixtureList;
 
-    for (SceneValue scv : m_dumpValues)
+    for (SceneValue &scv : m_dumpValues)
         if (!fixtureList.contains(scv.fxi))
             fixtureList.append(scv.fxi);
 
@@ -424,12 +424,15 @@ void SimpleDesk::dumpDmxChannels(QString name, quint32 mask)
  * Keypad
  ************************************************************************/
 
-void SimpleDesk::sendKeypadCommand(QString command)
+bool SimpleDesk::sendKeypadCommand(QString command)
 {
+    if (command.isEmpty())
+        return false;
+
     QByteArray uniData = m_prevUniverseValues.value(m_universeFilter);
     QList<SceneValue> scvList = m_keyPadParser->parseCommand(m_doc, command, uniData);
 
-    for (SceneValue scv : scvList)
+    for (SceneValue &scv : scvList)
     {
         quint32 fxID = m_doc->fixtureForAddress((m_universeFilter * 512) + scv.channel);
         Fixture *fixture = m_doc->fixture(fxID);
@@ -446,6 +449,8 @@ void SimpleDesk::sendKeypadCommand(QString command)
         m_keypadCommandHistory.removeLast();
 
     emit commandHistoryChanged();
+
+    return true;
 }
 
 QStringList SimpleDesk::commandHistory() const
