@@ -328,6 +328,9 @@ void VirtualConsole::deletePage(int index)
     if (index < 0 || index >= m_pages.count())
         return;
 
+    if (m_pages.count() == 1)
+        return;
+
     m_pages.at(index)->deleteChildren();
     VCPage *page = m_pages.takeAt(index);
     m_contextManager->unregisterContext(page->previewContext()->name());
@@ -787,7 +790,7 @@ QString VirtualConsole::widgetIcon(int type)
         case VCWidget::XYPadWidget: return "qrc:/xypad.svg";
         case VCWidget::FrameWidget: return "qrc:/frame.svg";
         case VCWidget::SoloFrameWidget: return "qrc:/soloframe.svg";
-        case VCWidget::SpeedDialWidget: return "qrc:/speed.svg";
+        case VCWidget::SpeedWidget: return "qrc:/speed.svg";
         case VCWidget::CueListWidget: return "qrc:/cuelist.svg";
         case VCWidget::LabelWidget: return "qrc:/label.svg";
         case VCWidget::AudioTriggersWidget: return "qrc:/audiotriggers.svg";
