@@ -18,6 +18,7 @@
 */
 
 #include <QApplication>
+#include <QMouseEvent>
 #include <QPainter>
 #include <QScreen>
 #include <qmath.h>
@@ -27,7 +28,6 @@
 #include "clickandgowidget.h"
 #include "qlccapability.h"
 #include "qlcmacros.h"
-#include "vcslider.h"
 #include "gradient.h"
 
 #define CELL_W  150
@@ -55,6 +55,8 @@ ClickAndGoWidget::ClickAndGoWidget(QWidget *parent) :
     m_cellBarXpos = 1;
     m_cellBarYpos = 1;
     m_cellBarWidth = 0;
+    m_levelLowLimit = 0;
+    m_levelHighLimit = 255;
 }
 
 void ClickAndGoWidget::setupGradient(QColor begin, QColor end)
@@ -146,6 +148,16 @@ void ClickAndGoWidget::setType(int type, const QLCChannel *chan)
     m_type = type;
 }
 
+void ClickAndGoWidget::setLevelLowLimit(int min)
+{
+    this->m_levelLowLimit = min;
+}
+
+void ClickAndGoWidget::setLevelHighLimit(int max)
+{
+    this->m_levelHighLimit = max;
+}
+
 int ClickAndGoWidget::getType()
 {
     return m_type;
@@ -210,9 +222,9 @@ QImage ClickAndGoWidget::getImageFromValue(uchar value)
      *  the pre-loaded resource */
     if (m_type == Preset)
     {
-        foreach(PresetResource res, m_resources)
+        foreach (PresetResource res, m_resources)
         {
-            if (value >= res.m_min && value <= res.m_max)
+            if (value >= res.m_resLowLimit && value <= res.m_resHighLimit)
                 return res.m_thumbnail;
         }
     }
@@ -242,7 +254,7 @@ void ClickAndGoWidget::createPresetList(const QLCChannel *chan)
 
     //qDebug() << Q_FUNC_INFO << "cap #" << chan->capabilities().size();
 
-    foreach(QLCCapability* cap, chan->capabilities())
+    foreach (QLCCapability* cap, chan->capabilities())
     {
         if (cap->presetType() == QLCCapability::Picture)
         {
@@ -315,6 +327,8 @@ void ClickAndGoWidget::setupPresetPicker()
     for (int i = 0; i < m_resources.size(); i++)
     {
         PresetResource res = m_resources.at(i);
+        if (res.m_resLowLimit > m_levelHighLimit || res.m_resHighLimit < m_levelLowLimit)
+            continue;
         painter.setPen(Qt::black);
         painter.drawRect(x, y, m_cellWidth, CELL_H);
         painter.drawImage(x + 1, y + 4, res.m_thumbnail);
@@ -355,13 +369,13 @@ void ClickAndGoWidget::mousePressEvent(QMouseEvent *event)
         if (m_hoverCellIdx >= 0 && m_hoverCellIdx < m_resources.length())
         {
             PresetResource res = m_resources.at(m_hoverCellIdx);
-            qDebug() << "Mouse press. cellW: " << m_cellBarWidth << "min: " << res.m_min << "max:" << res.m_max;
+            qDebug() << "Mouse press. cellW: " << m_cellBarWidth << "min: " << res.m_resLowLimit << "max:" << res.m_resHighLimit;
 
             float f = SCALE(float(m_cellBarWidth),
                         float(0),
                         float(m_cellWidth),
-                        float(0), float(res.m_max - res.m_min));
-            emit levelAndPresetChanged((uchar)f + res.m_min, res.m_thumbnail);
+                        float(0), float(res.m_resHighLimit - res.m_resLowLimit));
+            emit levelAndPresetChanged((uchar)f + res.m_resLowLimit, res.m_thumbnail);
         }
     }
     QWidget::mousePressEvent(event);
@@ -421,8 +435,8 @@ void ClickAndGoWidget::paintEvent(QPaintEvent *event)
 ClickAndGoWidget::PresetResource::PresetResource(QString path, QString text, uchar min, uchar max)
 {
     m_descr = text;
-    m_min = min;
-    m_max = max;
+    m_resLowLimit = min;
+    m_resHighLimit = max;
     QImage px(path);
     m_thumbnail = QImage(40, 40, QImage::Format_RGB32);
     m_thumbnail.fill(Qt::white);
@@ -436,8 +450,8 @@ ClickAndGoWidget::PresetResource::PresetResource(QColor color1, QColor color2,
                                                  QString text, uchar min, uchar max)
 {
     m_descr = text;
-    m_min = min;
-    m_max = max;
+    m_resLowLimit = min;
+    m_resHighLimit = max;
     m_thumbnail = QImage(40, 40, QImage::Format_RGB32);
     if (color2.isValid() == false)
         m_thumbnail.fill(color1.rgb());
@@ -453,8 +467,8 @@ ClickAndGoWidget::PresetResource::PresetResource(QColor color1, QColor color2,
 ClickAndGoWidget::PresetResource::PresetResource(int index, QString text, uchar min, uchar max)
 {
     m_descr = text;
-    m_min = min;
-    m_max = max;
+    m_resLowLimit = min;
+    m_resHighLimit = max;
     m_thumbnail = QImage(40, 40, QImage::Format_RGB32);
     m_thumbnail.fill(Qt::white);
     QFont tfont = QApplication::font();
