@@ -17,14 +17,12 @@
   limitations under the License.
 */
 
+#include <QContextMenuEvent>
 #include <QDebug>
 
 #include "functionstreewidget.h"
 #include "function.h"
-#include "chaser.h"
-#include "scene.h"
 #include "doc.h"
-#include <QContextMenuEvent>
 
 #define COL_NAME 0
 #define COL_PATH 1
@@ -279,7 +277,7 @@ QTreeWidgetItem *FunctionsTreeWidget::folderItem(QString name)
     int type = Function::Undefined;
     QString fullPath;
     QStringList levelsList = name.split("/");
-    foreach(QString level, levelsList)
+    foreach (QString level, levelsList)
     {
         // the first round is a category node. Just retrieve the item pointer
         // and the type, then skip it.
