@@ -18,10 +18,13 @@
 */
 
 #include <QTreeWidgetItem>
+#include <QColorDialog>
+#include <QInputDialog>
 #include <QTextBrowser>
 #include <QTreeWidget>
 #include <QToolButton>
 #include <QMessageBox>
+#include <QPushButton>
 #include <QTabWidget>
 #include <QSettings>
 #include <QCheckBox>
@@ -63,6 +66,7 @@ InputProfileEditor::InputProfileEditor(QWidget* parent, QLCInputProfile* profile
     setupUi(this);
 
     m_midiGroupSettings->setVisible(false);
+
     connect(m_typeCombo, SIGNAL(currentIndexChanged(int)),
             this, SLOT(slotTypeComboChanged(int)));
 
@@ -89,6 +93,18 @@ InputProfileEditor::InputProfileEditor(QWidget* parent, QLCInputProfile* profile
             this, SLOT(slotLowerValueSpinChanged(int)));
     connect(m_upperSpin, SIGNAL(valueChanged(int)),
             this, SLOT(slotUpperValueSpinChanged(int)));
+    connect(m_midiChannelCombo, SIGNAL(currentIndexChanged(int)),
+            this, SLOT(slotMidiChannelComboChanged(int)));
+
+    connect(m_addColorButton, SIGNAL(clicked()),
+            this, SLOT(slotAddColor()));
+    connect(m_removeColorButton, SIGNAL(clicked()),
+            this, SLOT(slotRemoveColor()));
+
+    connect(m_addMidiChannelButton, SIGNAL(clicked()),
+            this, SLOT(slotAddMidiChannel()));
+    connect(m_removeMidiChannelButton, SIGNAL(clicked()),
+            this, SLOT(slotRemoveMidiChannel()));
 
     /* Listen to input data */
     connect(m_ioMap, SIGNAL(inputValueChanged(quint32, quint32, uchar, const QString&)),
@@ -100,7 +116,7 @@ InputProfileEditor::InputProfileEditor(QWidget* parent, QLCInputProfile* profile
     }
     else
     {
-        m_profile = new QLCInputProfile(*profile);
+        m_profile = profile->createCopy();
         if ((QFile::permissions(m_profile->path()) &
                 QFile::WriteUser) == 0)
         {
@@ -135,9 +151,16 @@ InputProfileEditor::InputProfileEditor(QWidget* parent, QLCInputProfile* profile
 
     m_behaviourBox->hide();
     m_feedbackGroup->hide();
+
     /* Fill up the tree with profile's channels */
     fillTree();
 
+    /* Fill up the tree with color table */
+    updateColorsTree();
+
+    /* Fill up the tree with MIDI channel table */
+    updateMidiChannelTree();
+
     /* Timer that clears the input data icon after a while */
     m_timer = new QTimer(this);
     m_timer->setSingleShot(true);
@@ -171,8 +194,57 @@ void InputProfileEditor::fillTree()
     m_tree->header()->resizeSections(QHeaderView::ResizeToContents);
 }
 
-void InputProfileEditor::updateChannelItem(QTreeWidgetItem* item,
-                                           QLCInputChannel* ch)
+void InputProfileEditor::updateColorsTree()
+{
+    m_colorTableTree->clear();
+
+    QMapIterator <uchar, QPair<QString, QColor>> it(m_profile->colorTable());
+    while (it.hasNext() == true)
+    {
+        it.next();
+        QPair<QString, QColor> lc = it.value();
+        QTreeWidgetItem *item = new QTreeWidgetItem(m_colorTableTree);
+        item->setText(0, QString::number(it.key()));
+        item->setText(1, lc.first);
+
+        QLabel *colLabel = new QLabel();
+        colLabel->setStyleSheet(QString("background-color: %1").arg(lc.second.name()));
+
+        m_colorTableTree->setItemWidget(item, 2, colLabel);
+    }
+}
+
+void InputProfileEditor::updateMidiChannelTree()
+{
+    m_midiChannelsTree->clear();
+    m_midiChannelCombo->clear();
+
+    if (m_profile->hasMidiChannelTable())
+    {
+        m_midiChannelCombo->show();
+        m_midiChannelLabel->show();
+        m_midiChannelCombo->addItem(tr("From plugin settings"));
+    }
+    else
+    {
+        m_midiChannelCombo->hide();
+        m_midiChannelLabel->hide();
+    }
+
+    QMapIterator <uchar, QString> it(m_profile->midiChannelTable());
+    while (it.hasNext() == true)
+    {
+        it.next();
+        QTreeWidgetItem *item = new QTreeWidgetItem(m_midiChannelsTree);
+        item->setText(0, QString::number(it.key() + 1));
+        item->setText(1, it.value());
+
+        m_midiChannelCombo->addItem(it.value());
+    }
+}
+
+void InputProfileEditor::updateChannelItem(QTreeWidgetItem *item,
+                                           QLCInputChannel *ch)
 {
     quint32 num;
 
@@ -222,10 +294,15 @@ void InputProfileEditor::setOptionsVisibility(QLCInputChannel::Type type)
 
 void InputProfileEditor::slotTypeComboChanged(int)
 {
+    bool showMidiSettings = false;
+
     if (currentProfileType() == QLCInputProfile::MIDI)
-        m_midiGroupSettings->setVisible(true);
-    else
-        m_midiGroupSettings->setVisible(false);
+    {
+        showMidiSettings = true;
+        updateMidiChannelTree();
+    }
+
+    m_midiGroupSettings->setVisible(showMidiSettings);
 }
 
 /****************************************************************************
@@ -256,7 +333,7 @@ void InputProfileEditor::accept()
 
     /* Check that we have at least the bare necessities to save the profile */
     if (m_profile->manufacturer().isEmpty() == true ||
-            m_profile->model().isEmpty() == true)
+        m_profile->model().isEmpty() == true)
     {
         QMessageBox::warning(this, tr("Missing information"),
                              tr("Manufacturer and/or model name is missing."));
@@ -501,10 +578,13 @@ void InputProfileEditor::slotItemClicked(QTreeWidgetItem *item, int col)
             m_extraPressCheck->setChecked(ich->sendExtraPress());
             m_lowerSpin->blockSignals(true);
             m_upperSpin->blockSignals(true);
+            m_midiChannelCombo->blockSignals(true);
             m_lowerSpin->setValue(ich->lowerValue());
             m_upperSpin->setValue(ich->upperValue());
+            m_midiChannelCombo->setCurrentIndex(ich->lowerChannel() + 1);
             m_lowerSpin->blockSignals(false);
             m_upperSpin->blockSignals(false);
+            m_midiChannelCombo->blockSignals(false);
         }
     }
     else
@@ -518,7 +598,7 @@ void InputProfileEditor::slotMovementComboChanged(int index)
     else
         m_sensitivitySpin->setEnabled(false);
 
-    foreach(QLCInputChannel *channel, selectedChannels())
+    foreach (QLCInputChannel *channel, selectedChannels())
     {
         if (channel->type() == QLCInputChannel::Slider ||
             channel->type() == QLCInputChannel::Knob)
@@ -533,7 +613,7 @@ void InputProfileEditor::slotMovementComboChanged(int index)
 
 void InputProfileEditor::slotSensitivitySpinChanged(int value)
 {
-    foreach(QLCInputChannel *channel, selectedChannels())
+    foreach (QLCInputChannel *channel, selectedChannels())
     {
         if ((channel->type() == QLCInputChannel::Slider ||
              channel->type() == QLCInputChannel::Knob) &&
@@ -546,16 +626,16 @@ void InputProfileEditor::slotSensitivitySpinChanged(int value)
 
 void InputProfileEditor::slotExtraPressChecked(bool checked)
 {
-    foreach(QLCInputChannel *channel, selectedChannels())
+    foreach (QLCInputChannel *channel, selectedChannels())
     {
-        if(channel->type() == QLCInputChannel::Button)
+        if (channel->type() == QLCInputChannel::Button)
             channel->setSendExtraPress(checked);
     }
 }
 
 void InputProfileEditor::slotLowerValueSpinChanged(int value)
 {
-    foreach(QLCInputChannel *channel, selectedChannels())
+    foreach (QLCInputChannel *channel, selectedChannels())
     {
         if (channel->type() == QLCInputChannel::Button)
             channel->setRange(uchar(value), uchar(m_upperSpin->value()));
@@ -564,13 +644,71 @@ void InputProfileEditor::slotLowerValueSpinChanged(int value)
 
 void InputProfileEditor::slotUpperValueSpinChanged(int value)
 {
-    foreach(QLCInputChannel *channel, selectedChannels())
+    foreach (QLCInputChannel *channel, selectedChannels())
     {
         if (channel->type() == QLCInputChannel::Button)
             channel->setRange(uchar(m_lowerSpin->value()), uchar(value));
     }
 }
 
+void InputProfileEditor::slotMidiChannelComboChanged(int index)
+{
+    foreach (QLCInputChannel *channel, selectedChannels())
+    {
+        if (channel->type() == QLCInputChannel::Button)
+            channel->setLowerChannel(index - 1);
+    }
+}
+
+void InputProfileEditor::slotAddColor()
+{
+    bool ok;
+    int val = QInputDialog::getInt(this, tr("Enter value"), tr("Feedback value"), 0, 0, 255, 1, &ok);
+
+    if (ok)
+    {
+        QColor color = QColorDialog::getColor();
+
+        QString label = QInputDialog::getText(this, tr("Enter label"), tr("Color label"));
+        m_profile->addColor(val, label, color);
+        updateColorsTree();
+        m_colorTableTree->scrollToBottom();
+    }
+}
+
+void InputProfileEditor::slotRemoveColor()
+{
+    foreach (QTreeWidgetItem *item, m_colorTableTree->selectedItems())
+    {
+        uchar value = uchar(item->text(0).toInt());
+        m_profile->removeColor(value);
+    }
+    updateColorsTree();
+}
+
+void InputProfileEditor::slotAddMidiChannel()
+{
+    bool ok;
+    int val = QInputDialog::getInt(this, tr("Enter value"), tr("MIDI channel"), 1, 1, 16, 1, &ok);
+
+    if (ok)
+    {
+        QString label = QInputDialog::getText(this, tr("Enter label"), tr("MIDI channel label"));
+        m_profile->addMidiChannel(val - 1, label);
+        updateMidiChannelTree();
+    }
+}
+
+void InputProfileEditor::slotRemoveMidiChannel()
+{
+    foreach (QTreeWidgetItem *item, m_midiChannelsTree->selectedItems())
+    {
+        uchar value = uchar(item->text(0).toInt());
+        m_profile->removeMidiChannel(value);
+    }
+    updateMidiChannelTree();
+}
+
 void InputProfileEditor::slotInputValueChanged(quint32 universe,
                                                quint32 channel,
                                                uchar value,
@@ -596,7 +734,7 @@ void InputProfileEditor::slotInputValueChanged(quint32 universe,
         /* No channel items found. Create a new channel to the
            profile and display it also in the tree widget */
         QLCInputChannel* ch = new QLCInputChannel();
-        if(key.isEmpty())
+        if (key.isEmpty())
             ch->setName(tr("Button %1").arg(channel + 1));
         else
             ch->setName(key);
@@ -636,7 +774,7 @@ void InputProfileEditor::slotInputValueChanged(quint32 universe,
             if (ch->type() == QLCInputChannel::Button)
             {
                 ch->setType(QLCInputChannel::Slider);
-                if(key.isEmpty())
+                if (key.isEmpty())
                     ch->setName(tr("Slider %1").arg(channel + 1));
                 else
                     ch->setName(key);
@@ -667,7 +805,7 @@ void InputProfileEditor::slotTimerTimeout()
  * Profile
  ****************************************************************************/
 
-const QLCInputProfile* InputProfileEditor::profile() const
+QLCInputProfile* InputProfileEditor::profile()
 {
     return m_profile;
 }
