@@ -28,7 +28,6 @@
 #include "monitorfixtureitem.h"
 #include "qlcfixturehead.h"
 #include "qlcfixturemode.h"
-#include "qlcfixturedef.h"
 #include "qlccapability.h"
 #include "fixture.h"
 #include "doc.h"
@@ -249,7 +248,7 @@ MonitorFixtureItem::~MonitorFixtureItem()
             disconnect(fxi, SIGNAL(valuesChanged()), this, SLOT(slotUpdateValues()));
     }
 
-    foreach(FixtureHead *head, m_heads)
+    foreach (FixtureHead *head, m_heads)
     {
         if (head->m_strobeTimer != 0)
         {
@@ -440,7 +439,7 @@ void MonitorFixtureItem::slotUpdateValues()
 
     bool needUpdate = false;
 
-    foreach(FixtureHead *head, m_heads)
+    foreach (FixtureHead *head, m_heads)
     {
         head->m_color = computeColor(head, fxValues);
         head->m_dimmerValue = computeAlpha(head, fxValues);
