@@ -174,14 +174,32 @@ void RGBMatrixEditor::init()
     fillImageAnimationCombo();
 
     QPixmap pm(50, 26);
-    pm.fill(m_matrix->startColor());
-    m_startColorButton->setIcon(QIcon(pm));
+    pm.fill(m_matrix->getColor(0));
+    m_mtxColor1Button->setIcon(QIcon(pm));
 
-    if (m_matrix->endColor().isValid())
-        pm.fill(m_matrix->endColor());
+    if (m_matrix->getColor(1).isValid())
+        pm.fill(m_matrix->getColor(1));
     else
         pm.fill(Qt::transparent);
-    m_endColorButton->setIcon(QIcon(pm));
+    m_mtxColor2Button->setIcon(QIcon(pm));
+
+    if (m_matrix->getColor(2).isValid())
+        pm.fill(m_matrix->getColor(2));
+    else
+        pm.fill(Qt::transparent);
+    m_mtxColor3Button->setIcon(QIcon(pm));
+
+    if (m_matrix->getColor(3).isValid())
+        pm.fill(m_matrix->getColor(3));
+    else
+        pm.fill(Qt::transparent);
+    m_mtxColor4Button->setIcon(QIcon(pm));
+
+    if (m_matrix->getColor(4).isValid())
+        pm.fill(m_matrix->getColor(4));
+    else
+        pm.fill(Qt::transparent);
+    m_mtxColor5Button->setIcon(QIcon(pm));
 
     updateExtraOptions();
     updateSpeedDials();
@@ -202,12 +220,24 @@ void RGBMatrixEditor::init()
             this, SLOT(slotBlendModeChanged(int)));
     connect(m_controlModeCombo, SIGNAL(activated(int)),
             this, SLOT(slotControlModeChanged(int)));
-    connect(m_startColorButton, SIGNAL(clicked()),
-            this, SLOT(slotStartColorButtonClicked()));
-    connect(m_endColorButton, SIGNAL(clicked()),
-            this, SLOT(slotEndColorButtonClicked()));
-    connect(m_resetEndColorButton, SIGNAL(clicked()),
-            this, SLOT(slotResetEndColorButtonClicked()));
+    connect(m_mtxColor1Button, SIGNAL(clicked()),
+            this, SLOT(slotMtxColor1ButtonClicked()));
+    connect(m_mtxColor2Button, SIGNAL(clicked()),
+            this, SLOT(slotMtxColor2ButtonClicked()));
+    connect(m_resetMtxColor2Button, SIGNAL(clicked()),
+            this, SLOT(slotResetMtxColor2ButtonClicked()));
+    connect(m_mtxColor3Button, SIGNAL(clicked()),
+            this, SLOT(slotMtxColor3ButtonClicked()));
+    connect(m_resetMtxColor3Button, SIGNAL(clicked()),
+            this, SLOT(slotResetMtxColor3ButtonClicked()));
+    connect(m_mtxColor4Button, SIGNAL(clicked()),
+            this, SLOT(slotMtxColor4ButtonClicked()));
+    connect(m_resetMtxColor4Button, SIGNAL(clicked()),
+            this, SLOT(slotResetMtxColor4ButtonClicked()));
+    connect(m_mtxColor5Button, SIGNAL(clicked()),
+            this, SLOT(slotMtxColor5ButtonClicked()));
+    connect(m_resetMtxColor5Button, SIGNAL(clicked()),
+            this, SLOT(slotResetMtxColor5ButtonClicked()));
     connect(m_textEdit, SIGNAL(textEdited(const QString&)),
             this, SLOT(slotTextEdited(const QString&)));
     connect(m_fontButton, SIGNAL(clicked()),
@@ -364,34 +394,27 @@ void RGBMatrixEditor::updateExtraOptions()
         m_yOffsetSpin->setValue(text->yOffset());
     }
 
+    updateColorOptions();
+}
+
+void RGBMatrixEditor::updateColorOptions()
+{
     if (m_matrix->algorithm() != NULL)
     {
         int accColors = m_matrix->algorithm()->acceptColors();
-        if (accColors == 0)
-        {
-            m_startColorButton->hide();
-            m_endColorButton->hide();
-            m_resetEndColorButton->hide();
-            m_blendModeLabel->hide();
-            m_blendModeCombo->hide();
-        }
-        else
-        {
-            m_startColorButton->show();
 
-            if (accColors == 1 || m_blendModeCombo->currentIndex() == Universe::MaskBlend)
-            {
-                m_endColorButton->hide();
-                m_resetEndColorButton->hide();
-            }
-            else // accColors > 1
-            {
-                m_endColorButton->show();
-                m_resetEndColorButton->show();
-            }
-            m_blendModeLabel->show();
-            m_blendModeCombo->show();
-        }
+        m_mtxColor1Button->setVisible(accColors == 0 ? false : true);
+        m_mtxColor2Button->setVisible(accColors > 1 ? true : false);
+        m_resetMtxColor2Button->setVisible(accColors > 1 ? true : false);
+        m_mtxColor3Button->setVisible(accColors > 2 ? true : false);
+        m_resetMtxColor3Button->setVisible(accColors > 2 ? true : false);
+        m_mtxColor4Button->setVisible(accColors > 3 ? true : false);
+        m_resetMtxColor4Button->setVisible(accColors > 3 ? true : false);
+        m_mtxColor5Button->setVisible(accColors > 4 ? true : false);
+        m_resetMtxColor5Button->setVisible(accColors > 4 ? true : false);
+
+        m_blendModeLabel->setVisible(accColors == 0 ? false : true);
+        m_blendModeCombo->setVisible(accColors == 0 ? false : true);
     }
 }
 
@@ -404,56 +427,133 @@ void RGBMatrixEditor::updateColors()
         {
             if (m_matrix->blendMode() == Universe::MaskBlend)
             {
-                m_matrix->setStartColor(Qt::white);
-                m_matrix->setEndColor(QColor());
+                m_matrix->setColor(0, Qt::white);
+                // Overwrite more colors only if applied.
+                if (accColors <= 2)
+                    m_matrix->setColor(1, QColor());
+                if (accColors <= 3)
+                    m_matrix->setColor(2, QColor());
+                if (accColors <= 4)
+                    m_matrix->setColor(3, QColor());
+                if (accColors <= 5)
+                    m_matrix->setColor(4, QColor());
 
-                m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+                m_previewHandler->calculateColorDelta(m_matrix->getColor(0), m_matrix->getColor(1),
+                        m_matrix->algorithm());
 
                 QPixmap pm(50, 26);
                 pm.fill(Qt::white);
-                m_startColorButton->setIcon(QIcon(pm));
+                m_mtxColor1Button->setIcon(QIcon(pm));
+
+                pm.fill(Qt::transparent);
+                m_mtxColor2Button->setIcon(QIcon(pm));
+                m_mtxColor3Button->setIcon(QIcon(pm));
+                m_mtxColor4Button->setIcon(QIcon(pm));
+                m_mtxColor5Button->setIcon(QIcon(pm));
             }
             else if (m_controlModeCombo->currentIndex() != RGBMatrix::ControlModeRgb)
             {
-                // Convert startColor to grayscale for single color modes
-                uchar gray = qGray(m_matrix->startColor().rgb());
+                // Convert color 1 to grayscale for single color modes
+                uchar gray = qGray(m_matrix->getColor(0).rgb());
+                m_matrix->setColor(0, QColor(gray, gray, gray));
                 QPixmap pm(50, 26);
                 pm.fill(QColor(gray, gray, gray));
-                m_startColorButton->setIcon(QIcon(pm));
-                m_matrix->setStartColor(QColor(gray, gray, gray));
+                m_mtxColor1Button->setIcon(QIcon(pm));
 
-                if (accColors > 1)
+                // Convert color 2 and following to grayscale for single color modes
+                if (accColors < 2)
+                    m_matrix->setColor(1, QColor());
+                if (m_matrix->getColor(1) == QColor())
                 {
-                    // Convert endColor to grayscale for single color modes
-                    gray = qGray(m_matrix->endColor().rgb());
-                    m_matrix->setEndColor(QColor(gray, gray, gray));
-
-                    if (m_matrix->endColor() == QColor())
-                        pm.fill(Qt::transparent);
-                    else
-                        pm.fill(QColor(gray, gray, gray));
-
-                    m_endColorButton->setIcon(QIcon(pm));
+                    pm.fill(Qt::transparent);
                 }
-                m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+                else
+                {
+                    gray = qGray(m_matrix->getColor(1).rgb());
+                    m_matrix->setColor(1, QColor(gray, gray, gray));
+                    pm.fill(QColor(gray, gray, gray));
+                }
+                m_mtxColor2Button->setIcon(QIcon(pm));
+
+                if (accColors < 3)
+                    m_matrix->setColor(2, QColor());
+                if (m_matrix->getColor(2) == QColor())
+                {
+                    pm.fill(Qt::transparent);
+                }
+                else
+                {
+                    gray = qGray(m_matrix->getColor(2).rgb());
+                    m_matrix->setColor(2, QColor(gray, gray, gray));
+                    pm.fill(QColor(gray, gray, gray));
+                }
+                m_mtxColor3Button->setIcon(QIcon(pm));
+
+                if (accColors < 4)
+                    m_matrix->setColor(3, QColor());
+                if (m_matrix->getColor(3) == QColor())
+                {
+                    pm.fill(Qt::transparent);
+                }
+                else
+                {
+                    gray = qGray(m_matrix->getColor(3).rgb());
+                    m_matrix->setColor(3, QColor(gray, gray, gray));
+                    pm.fill(QColor(gray, gray, gray));
+                }
+                m_mtxColor4Button->setIcon(QIcon(pm));
+
+                if (accColors < 5)
+                    m_matrix->setColor(4, QColor());
+                if (m_matrix->getColor(4) == QColor())
+                {
+                    pm.fill(Qt::transparent);
+                }
+                else
+                {
+                    gray = qGray(m_matrix->getColor(4).rgb());
+                    m_matrix->setColor(4, QColor(gray, gray, gray));
+                    pm.fill(QColor(gray, gray, gray));
+                }
+                m_mtxColor5Button->setIcon(QIcon(pm));
+
+                m_previewHandler->calculateColorDelta(m_matrix->getColor(0), m_matrix->getColor(1),
+                        m_matrix->algorithm());
             }
             else 
             {
                 QPixmap pm(50, 26);
-                pm.fill(m_matrix->startColor());
-                m_startColorButton->setIcon(QIcon(pm));
+                pm.fill(m_matrix->getColor(0));
+                m_mtxColor1Button->setIcon(QIcon(pm));
 
-                if (accColors > 1)
-                {
-                    m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+                // Preserve the colors (do not set them to QColor().
+                // RGBMatrixStep::calculateColorDelta will ensure correct color application
+                if (m_matrix->getColor(1) == QColor())
+                    pm.fill(Qt::transparent);
+                else
+                    pm.fill(m_matrix->getColor(1));
+                m_mtxColor2Button->setIcon(QIcon(pm));
 
-                    if (m_matrix->endColor() == QColor())
-                        pm.fill(Qt::transparent);
-                    else
-                        pm.fill(m_matrix->endColor());
+                if (m_matrix->getColor(2) == QColor())
+                    pm.fill(Qt::transparent);
+                else
+                    pm.fill(m_matrix->getColor(2));
+                m_mtxColor3Button->setIcon(QIcon(pm));
 
-                    m_endColorButton->setIcon(QIcon(pm));
-                }
+                if (m_matrix->getColor(3) == QColor())
+                    pm.fill(Qt::transparent);
+                else
+                    pm.fill(m_matrix->getColor(3));
+                m_mtxColor4Button->setIcon(QIcon(pm));
+
+                if (m_matrix->getColor(4) == QColor())
+                    pm.fill(Qt::transparent);
+                else
+                    pm.fill(m_matrix->getColor(4));
+                m_mtxColor5Button->setIcon(QIcon(pm));
+
+                m_previewHandler->calculateColorDelta(m_matrix->getColor(0), m_matrix->getColor(1),
+                        m_matrix->algorithm());
             }
         }
     }
@@ -495,8 +595,8 @@ void RGBMatrixEditor::displayProperties(RGBScript *script)
                 QComboBox *propCombo = new QComboBox(this);
                 propCombo->addItems(prop.m_listValues);
                 propCombo->setProperty("pName", prop.m_name);
-                connect(propCombo, SIGNAL(currentIndexChanged(QString)),
-                        this, SLOT(slotPropertyComboChanged(QString)));
+                connect(propCombo, SIGNAL(currentIndexChanged(int)),
+                        this, SLOT(slotPropertyComboChanged(int)));
                 m_propertiesLayout->addWidget(propCombo, gridRowIdx, 1);
                 if (m_matrix != NULL)
                 {
@@ -612,8 +712,9 @@ bool RGBMatrixEditor::createPreviewItems()
         return false;
     }
 
-    m_previewHandler->initializeDirection(m_matrix->direction(), m_matrix->startColor(),
-                                          m_matrix->endColor(), m_matrix->stepsCount());
+    m_previewHandler->initializeDirection(m_matrix->direction(), m_matrix->getColor(0),
+                                      m_matrix->getColor(1), m_matrix->stepsCount(),
+                                      m_matrix->algorithm());
 
     m_matrix->previewMap(m_previewHandler->currentStepIndex(), m_previewHandler);
 
@@ -669,8 +770,8 @@ void RGBMatrixEditor::slotPreviewTimeout()
     uint elapsed = 0;
     while (m_previewIterator >= MAX(m_matrix->duration(), MasterTimer::tick()))
     {
-        m_previewHandler->checkNextStep(m_matrix->runOrder(), m_matrix->startColor(),
-                                        m_matrix->endColor(), m_matrix->stepsCount());
+        m_previewHandler->checkNextStep(m_matrix->runOrder(), m_matrix->getColor(0),
+                                        m_matrix->getColor(1), m_matrix->stepsCount());
 
         m_matrix->previewMap(m_previewHandler->currentStepIndex(), m_previewHandler);
 
@@ -725,10 +826,23 @@ void RGBMatrixEditor::slotPatternActivated(int patternIndex)
 {
     QString algoName = m_patternCombo->itemText(patternIndex);
     RGBAlgorithm *algo = RGBAlgorithm::algorithm(m_doc, algoName);
-    if (algo != NULL)
-        algo->setColors(m_matrix->startColor(), m_matrix->endColor());
     m_matrix->setAlgorithm(algo);
-    m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+    if (algo != NULL) {
+        updateColors();
+#if (5 != RGBAlgorithmColorDisplayCount)
+#error "Further colors need to be displayed."
+#endif
+        QVector<QColor> colors = {
+                m_matrix->getColor(0),
+                m_matrix->getColor(1),
+                m_matrix->getColor(2),
+                m_matrix->getColor(3),
+                m_matrix->getColor(4)
+        };
+        algo->setColors(colors);
+        m_previewHandler->calculateColorDelta(m_matrix->getColor(0), m_matrix->getColor(1),
+                m_matrix->algorithm());
+    }
     updateExtraOptions();
 
     slotRestartTest();
@@ -756,11 +870,11 @@ void RGBMatrixEditor::slotBlendModeChanged(int index)
 
     if (index == Universe::MaskBlend)
     {
-        m_startColorButton->setEnabled(false);
+        m_mtxColor1Button->setEnabled(false);
     }
     else
     {
-        m_startColorButton->setEnabled(true);
+        m_mtxColor1Button->setEnabled(true);
     }
     updateExtraOptions();
     updateColors();
@@ -775,32 +889,85 @@ void RGBMatrixEditor::slotControlModeChanged(int index)
     slotRestartTest();
 }
 
-void RGBMatrixEditor::slotStartColorButtonClicked()
+void RGBMatrixEditor::slotMtxColor1ButtonClicked()
 {
-    QColor col = QColorDialog::getColor(m_matrix->startColor());
+    QColor col = QColorDialog::getColor(m_matrix->getColor(0));
     if (col.isValid() == true)
     {
-        m_matrix->setStartColor(col);
+        m_matrix->setColor(0, col);
         updateColors();
         slotRestartTest();
     }
 }
 
-void RGBMatrixEditor::slotEndColorButtonClicked()
+void RGBMatrixEditor::slotMtxColor2ButtonClicked()
 {
-    QColor col = QColorDialog::getColor(m_matrix->endColor());
+    QColor col = QColorDialog::getColor(m_matrix->getColor(1));
     if (col.isValid() == true)
     {
-        m_matrix->setEndColor(col);
+        m_matrix->setColor(1, col);
         updateColors();
         slotRestartTest();
     }
 }
 
-void RGBMatrixEditor::slotResetEndColorButtonClicked()
+void RGBMatrixEditor::slotResetMtxColor2ButtonClicked()
 {
-    m_matrix->setEndColor(QColor());
-    m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+    m_matrix->setColor(1, QColor());
+    updateColors();
+    slotRestartTest();
+}
+
+void RGBMatrixEditor::slotMtxColor3ButtonClicked()
+{
+    QColor col = QColorDialog::getColor(m_matrix->getColor(2));
+    if (col.isValid() == true)
+    {
+        m_matrix->setColor(2, col);
+        updateColors();
+        slotRestartTest();
+    }
+}
+
+void RGBMatrixEditor::slotResetMtxColor3ButtonClicked()
+{
+    m_matrix->setColor(2, QColor());
+    updateColors();
+    slotRestartTest();
+}
+
+void RGBMatrixEditor::slotMtxColor4ButtonClicked()
+{
+    QColor col = QColorDialog::getColor(m_matrix->getColor(3));
+    if (col.isValid() == true)
+    {
+        m_matrix->setColor(3, col);
+        updateColors();
+        slotRestartTest();
+    }
+}
+
+void RGBMatrixEditor::slotResetMtxColor4ButtonClicked()
+{
+    m_matrix->setColor(3, QColor());
+    updateColors();
+    slotRestartTest();
+}
+
+void RGBMatrixEditor::slotMtxColor5ButtonClicked()
+{
+    QColor col = QColorDialog::getColor(m_matrix->getColor(4));
+    if (col.isValid() == true)
+    {
+        m_matrix->setColor(4, col);
+        updateColors();
+        slotRestartTest();
+    }
+}
+
+void RGBMatrixEditor::slotResetMtxColor5ButtonClicked()
+{
+    m_matrix->setColor(4, QColor());
     updateColors();
     slotRestartTest();
 }
@@ -937,35 +1104,40 @@ void RGBMatrixEditor::slotOffsetSpinChanged()
 void RGBMatrixEditor::slotLoopClicked()
 {
     m_matrix->setRunOrder(Function::Loop);
-    m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+    m_previewHandler->calculateColorDelta(m_matrix->getColor(0), m_matrix->getColor(1),
+            m_matrix->algorithm());
     slotRestartTest();
 }
 
 void RGBMatrixEditor::slotPingPongClicked()
 {
     m_matrix->setRunOrder(Function::PingPong);
-    m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+    m_previewHandler->calculateColorDelta(m_matrix->getColor(0), m_matrix->getColor(1),
+            m_matrix->algorithm());
     slotRestartTest();
 }
 
 void RGBMatrixEditor::slotSingleShotClicked()
 {
     m_matrix->setRunOrder(Function::SingleShot);
-    m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+    m_previewHandler->calculateColorDelta(m_matrix->getColor(0), m_matrix->getColor(1),
+            m_matrix->algorithm());
     slotRestartTest();
 }
 
 void RGBMatrixEditor::slotForwardClicked()
 {
     m_matrix->setDirection(Function::Forward);
-    m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+    m_previewHandler->calculateColorDelta(m_matrix->getColor(0), m_matrix->getColor(1),
+            m_matrix->algorithm());
     slotRestartTest();
 }
 
 void RGBMatrixEditor::slotBackwardClicked()
 {
     m_matrix->setDirection(Function::Backward);
-    m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+    m_previewHandler->calculateColorDelta(m_matrix->getColor(0), m_matrix->getColor(1),
+            m_matrix->algorithm());
     slotRestartTest();
 }
 
@@ -1150,16 +1322,17 @@ void RGBMatrixEditor::slotSaveToSequenceClicked()
         int totalSteps = m_matrix->stepsCount();
         int increment = 1;
         int currentStep = 0;
-        m_previewHandler->setStepColor(m_matrix->startColor());
+        m_previewHandler->setStepColor(m_matrix->getColor(0));
 
         if (m_matrix->direction() == Function::Backward)
         {
             currentStep = totalSteps - 1;
             increment = -1;
-            if (m_matrix->endColor().isValid())
-                m_previewHandler->setStepColor(m_matrix->endColor());
+            if (m_matrix->getColor(1).isValid())
+                m_previewHandler->setStepColor(m_matrix->getColor(1));
         }
-        m_previewHandler->calculateColorDelta(m_matrix->startColor(), m_matrix->endColor());
+        m_previewHandler->calculateColorDelta(m_matrix->getColor(0), m_matrix->getColor(1),
+                m_matrix->algorithm());
 
         if (m_matrix->runOrder() == RGBMatrix::PingPong)
             totalSteps = (totalSteps * 2) - 1;
@@ -1266,7 +1439,7 @@ void RGBMatrixEditor::slotSaveToSequenceClicked()
                 currentStep = totalSteps - 2;
                 increment = -1;
             }
-            m_previewHandler->updateStepColor(currentStep, m_matrix->startColor(), m_matrix->stepsCount());
+            m_previewHandler->updateStepColor(currentStep, m_matrix->getColor(0), m_matrix->stepsCount());
         }
 
         m_doc->addFunction(sequence);
@@ -1283,15 +1456,19 @@ void RGBMatrixEditor::slotShapeToggle(bool)
     createPreviewItems();
 }
 
-void RGBMatrixEditor::slotPropertyComboChanged(QString value)
+void RGBMatrixEditor::slotPropertyComboChanged(int index)
 {
-    qDebug() << "Property combo changed to" << value;
     if (m_matrix->algorithm() == NULL ||
         m_matrix->algorithm()->type() == RGBAlgorithm::Script)
     {
         QComboBox *combo = qobject_cast<QComboBox *>(sender());
         QString pName = combo->property("pName").toString();
-        m_matrix->setProperty(pName, value);
+        QString pValue = combo->itemText(index);
+        qDebug() << "Property combo changed to" << pValue;
+        m_matrix->setProperty(pName, pValue);
+
+        updateColorOptions();
+        updateColors();
     }
 }
 
