@@ -83,6 +83,7 @@ void SequenceItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
         uint stepFadeIn = step.fadeIn;
         uint stepFadeOut = step.fadeOut;
         uint stepDuration = step.duration;
+
         if (m_chaser->fadeInMode() == Chaser::Common)
             stepFadeIn = m_chaser->fadeInSpeed();
         if (m_chaser->fadeOutMode() == Chaser::Common)
@@ -113,6 +114,10 @@ void SequenceItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
             painter->setBrush(QBrush(Qt::NoBrush));
             painter->drawRect(xpos, 0, stepWidth, TRACK_HEIGHT - 3);
         }
+
+        QRect textRect = QRect(xpos + 1, 0, stepWidth - 1, TRACK_HEIGHT - 3);
+        painter->drawText(textRect, Qt::AlignBottom, step.note);
+
         xpos += stepWidth;
 
         // draw step vertical delimiter
