@@ -63,6 +63,7 @@ ShowManager::ShowManager(QWidget* parent, Doc* doc)
     , m_currentEditor(NULL)
     , m_editorFunctionID(Function::invalidId())
     , m_selectedShowIndex(-1)
+    , cursorMovedDuringPause(false)
     , m_splitter(NULL)
     , m_vsplitter(NULL)
     , m_showview(NULL)
@@ -109,8 +110,8 @@ ShowManager::ShowManager(QWidget* parent, Doc* doc)
     m_showview->setAcceptDrops(true);
     m_showview->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     m_showview->setBackgroundBrush(QBrush(QColor(88, 88, 88, 255), Qt::SolidPattern));
-    connect(m_showview, SIGNAL(viewClicked ( QMouseEvent * )),
-            this, SLOT(slotViewClicked( QMouseEvent * )));
+    connect(m_showview, SIGNAL(viewClicked(QMouseEvent *)),
+            this, SLOT(slotViewClicked(QMouseEvent *)));
 
     connect(m_showview, SIGNAL(showItemMoved(ShowItem*,quint32,bool)),
             this, SLOT(slotShowItemMoved(ShowItem*,quint32,bool)));
@@ -345,10 +346,10 @@ void ShowManager::initToolbar()
 
     m_timeDivisionCombo = new QComboBox();
     m_timeDivisionCombo->setFixedWidth(100);
-    m_timeDivisionCombo->addItem(tr("Time"), ShowHeaderItem::Time);
-    m_timeDivisionCombo->addItem("BPM 4/4", ShowHeaderItem::BPM_4_4);
-    m_timeDivisionCombo->addItem("BPM 3/4", ShowHeaderItem::BPM_3_4);
-    m_timeDivisionCombo->addItem("BPM 2/4", ShowHeaderItem::BPM_2_4);
+    m_timeDivisionCombo->addItem(tr("Time"), Show::Time);
+    m_timeDivisionCombo->addItem("BPM 4/4", Show::BPM_4_4);
+    m_timeDivisionCombo->addItem("BPM 3/4", Show::BPM_3_4);
+    m_timeDivisionCombo->addItem("BPM 2/4", Show::BPM_2_4);
     m_toolbar->addWidget(m_timeDivisionCombo);
     connect(m_timeDivisionCombo, SIGNAL(currentIndexChanged(int)),
             this, SLOT(slotTimeDivisionTypeChanged(int)));
@@ -1063,9 +1064,9 @@ void ShowManager::slotPaste()
             else
             {
                 // Verify the Chaser copy steps against the current Scene
-                foreach(ChaserStep cs, sequence->steps())
+                foreach (ChaserStep cs, sequence->steps())
                 {
-                    foreach(SceneValue scv, cs.values)
+                    foreach (SceneValue scv, cs.values)
                     {
                         if (m_currentScene->checkValue(scv) == false)
                         {
@@ -1201,6 +1202,7 @@ void ShowManager::slotStartPlayback()
 
     if (m_show->isRunning() == false)
     {
+        cursorMovedDuringPause = false;
         m_show->start(m_doc->masterTimer(), functionParent(), m_showview->getTimeFromCursor());
         m_playAction->setIcon(QIcon(":/player_pause.png"));
     }
@@ -1209,7 +1211,17 @@ void ShowManager::slotStartPlayback()
         if (m_show->isPaused())
         {
             m_playAction->setIcon(QIcon(":/player_pause.png"));
-            m_show->setPause(false);
+            if (cursorMovedDuringPause)
+            {
+                m_show->stop(functionParent());
+                m_show->stopAndWait();
+                cursorMovedDuringPause = false;
+                m_show->start(m_doc->masterTimer(), functionParent(), m_showview->getTimeFromCursor());
+            }
+            else
+            {
+                m_show->setPause(false);
+            }
         }
         else
         {
@@ -1229,13 +1241,13 @@ void ShowManager::slotTimeDivisionTypeChanged(int idx)
     QVariant var = m_timeDivisionCombo->itemData(idx);
     if (var.isValid())
     {
-        m_showview->setHeaderType((ShowHeaderItem::TimeDivision)var.toInt());
+        m_showview->setHeaderType((Show::TimeDivision)var.toInt());
         if (idx > 0)
             m_bpmField->setEnabled(true);
         else
             m_bpmField->setEnabled(false);
         if (m_show != NULL)
-            m_show->setTimeDivision(ShowHeaderItem::tempoToString((ShowHeaderItem::TimeDivision)var.toInt()), m_bpmField->value());
+            m_show->setTimeDivision((Show::TimeDivision)var.toInt(), m_bpmField->value());
     }
 }
 
@@ -1244,7 +1256,7 @@ void ShowManager::slotBPMValueChanged(int value)
     m_showview->setBPMValue(value);
     QVariant var = m_timeDivisionCombo->itemData(m_timeDivisionCombo->currentIndex());
     if (var.isValid() && m_show != NULL)
-        m_show->setTimeDivision(ShowHeaderItem::tempoToString((ShowHeaderItem::TimeDivision)var.toInt()), m_bpmField->value());
+        m_show->setTimeDivision((Show::TimeDivision)var.toInt(), m_bpmField->value());
 }
 
 void ShowManager::slotViewClicked(QMouseEvent *event)
@@ -1338,7 +1350,7 @@ void ShowManager::slotShowItemMoved(ShowItem *item, quint32 time, bool moved)
         m_doc->setModified();
 }
 
-void ShowManager::slotupdateTimeAndCursor(quint32 msec_time)
+void ShowManager::slotUpdateTimeAndCursor(quint32 msec_time)
 {
     //qDebug() << Q_FUNC_INFO << "time: " << msec_time;
     slotUpdateTime(msec_time);
@@ -1369,6 +1381,9 @@ void ShowManager::slotUpdateTime(quint32 msec_time)
               .arg(s, 2, 10, QChar('0')).arg(msec_time / 10, 2, 10, QChar('0'));
 
     m_timeLabel->setText(str);
+
+    if (m_show != NULL && m_show->isPaused())
+        cursorMovedDuringPause = true;
 }
 
 void ShowManager::slotTrackClicked(Track *track)
@@ -1587,7 +1602,7 @@ void ShowManager::slotFunctionRemoved(quint32 id)
     foreach (Function *function, m_doc->functionsByType(Function::ShowType))
     {
         Show *show = qobject_cast<Show*>(function);
-        foreach(Track *track, show->tracks())
+        foreach (Track *track, show->tracks())
         {
             foreach (ShowFunction *sf, track->showFunctions())
             {
@@ -1630,19 +1645,19 @@ void ShowManager::updateMultiTrackView()
     // prevent m_show time division override
     disconnect(m_bpmField, SIGNAL(valueChanged(int)), this, SLOT(slotBPMValueChanged(int)));
 
-    m_bpmField->setValue(m_show->getTimeDivisionBPM());
-    m_showview->setBPMValue(m_show->getTimeDivisionBPM());
-    int tIdx = m_timeDivisionCombo->findData(QVariant(ShowHeaderItem::stringToTempo(m_show->getTimeDivisionType())));
+    m_bpmField->setValue(m_show->timeDivisionBPM());
+    m_showview->setBPMValue(m_show->timeDivisionBPM());
+    int tIdx = m_timeDivisionCombo->findData(QVariant(m_show->timeDivisionType()));
     m_timeDivisionCombo->setCurrentIndex(tIdx);
 
     connect(m_bpmField, SIGNAL(valueChanged(int)), this, SLOT(slotBPMValueChanged(int)));
-    connect(m_show, SIGNAL(timeChanged(quint32)), this, SLOT(slotupdateTimeAndCursor(quint32)));
+    connect(m_show, SIGNAL(timeChanged(quint32)), this, SLOT(slotUpdateTimeAndCursor(quint32)));
     connect(m_show, SIGNAL(showFinished()), this, SLOT(slotStopPlayback()));
     connect(m_show, SIGNAL(stopped(quint32)), this, SLOT(slotShowStopped()));
 
     Track *firstTrack = NULL;
 
-    foreach(Track *track, m_show->tracks())
+    foreach (Track *track, m_show->tracks())
     {
         if (firstTrack == NULL)
             firstTrack = track;
@@ -1657,7 +1672,7 @@ void ShowManager::updateMultiTrackView()
 
         m_showview->addTrack(track);
 
-        foreach(ShowFunction *sf, track->showFunctions())
+        foreach (ShowFunction *sf, track->showFunctions())
         {
             Function *fn = m_doc->function(sf->functionID());
             if (fn != NULL)
@@ -1725,7 +1740,7 @@ bool ShowManager::checkOverlapping(quint32 startTime, quint32 duration)
     if (m_currentTrack == NULL)
         return false;
 
-    foreach(ShowFunction *sf, m_currentTrack->showFunctions())
+    foreach (ShowFunction *sf, m_currentTrack->showFunctions())
     {
         Function *func = m_doc->function(sf->functionID());
         if (func != NULL)
