@@ -388,7 +388,9 @@ int SimpleDesk::getCurrentPage()
 uchar SimpleDesk::getAbsoluteChannelValue(uint address)
 {
     if (m_engine->hasChannel(address))
+    {
         return m_engine->value(address);
+    }
     else
     {
         QList<Universe*> ua = m_doc->inputOutputMap()->claimUniverses();
@@ -404,12 +406,57 @@ uchar SimpleDesk::getAbsoluteChannelValue(uint address)
 
 void SimpleDesk::setAbsoluteChannelValue(uint address, uchar value)
 {
+    if (address >= ((uint)m_doc->inputOutputMap()->universesCount() * 512))
+        return;
+
     m_engine->setValue(address, value);
 }
 
 void SimpleDesk::resetChannel(quint32 address)
 {
     m_engine->resetChannel(address);
+
+    quint32 start = (m_currentUniverse * 512) + (m_universePageSpin->value() - 1) * m_channelsPerPage;
+
+    if (m_viewModeButton->isChecked() == false)
+    {
+        if (address < start || address >= start + m_channelsPerPage)
+            return;
+
+        Fixture *fxi = m_doc->fixture(m_doc->fixtureForAddress(address));
+        ConsoleChannel *cc = m_universeSliders.value(address - start, NULL);
+        if (cc == NULL)
+            return;
+
+        if (fxi == NULL)
+        {
+            cc->setChannelStyleSheet(ssNone);
+        }
+        else
+        {
+            if (fxi->id() % 2)
+                cc->setChannelStyleSheet(ssEven);
+            else
+                cc->setChannelStyleSheet(ssOdd);
+        }
+    }
+    else
+    {
+        Fixture *fxi = m_doc->fixture(m_doc->fixtureForAddress(address));
+        if (fxi == NULL)
+            return;
+
+        FixtureConsole *fc = m_consoleList.value(fxi->id(), NULL);
+        if (fc == NULL)
+            return;
+
+        quint32 ch = address - fxi->universeAddress();
+
+        if (fxi->id() % 2 == 0)
+            fc->setChannelStylesheet(ch, ssOdd);
+        else
+            fc->setChannelStylesheet(ch, ssEven);
+    }
 }
 
 void SimpleDesk::resetUniverse()
@@ -421,6 +468,12 @@ void SimpleDesk::resetUniverse()
     m_universeResetButton->click();
 }
 
+void SimpleDesk::resetUniverse(int index)
+{
+    m_universesCombo->setCurrentIndex(index);
+    resetUniverse();
+}
+
 /****************************************************************************
  * Universe controls
  ****************************************************************************/
@@ -754,7 +807,9 @@ void SimpleDesk::slotUniverseResetClicked()
     m_engine->resetUniverse(m_currentUniverse);
     m_universePageSpin->setValue(1);
     if (m_viewModeButton->isChecked() == false)
+    {
         slotUniversePageChanged(1);
+    }
     else
     {
         QHashIterator <quint32,FixtureConsole*> it(m_consoleList);
@@ -971,7 +1026,11 @@ void SimpleDesk::slotUniverseWritten(quint32 idx, const QByteArray& universeData
                         break;
 
                     if (m_engine->hasChannel((startAddr + c) + (idx << 9)) == true)
+                    {
+                        fc->setValue(c, universeData.at(startAddr + c), false);
+                        fc->setChannelStylesheet(c, ssOverride);
                         continue;
+                    }
 
                     fc->blockSignals(true);
                     fc->setValue(c, universeData.at(startAddr + c), false);
