@@ -881,6 +881,7 @@ void VCSlider::slotResetButtonClicked()
         if (!fader.isNull())
             fader->removeAll();
     }
+    updateOverrideFeedback(false);
 
     emit monitorDMXValueChanged(m_monitorValue);
 }
@@ -1370,6 +1371,7 @@ void VCSlider::setSliderValue(uchar value, bool scale, bool external)
             {
                 m_resetButton->setStyleSheet(QString("QToolButton{ background: red; }"));
                 m_isOverriding = true;
+                updateOverrideFeedback(true);
             }
             setLevelValue(val, external);
             setClickAndGoWidgetFromLevel(val);
@@ -1510,6 +1512,13 @@ void VCSlider::updateFeedback()
     sendFeedback(fbv);
 }
 
+void VCSlider::updateOverrideFeedback(bool on)
+{
+    QSharedPointer<QLCInputSource> src = inputSource(overrideResetInputSourceId);
+    if (!src.isNull() && src->isValid() == true)
+        sendFeedback(src->feedbackValue(on ? QLCInputFeedback::UpperValue : QLCInputFeedback::LowerValue), overrideResetInputSourceId);
+}
+
 void VCSlider::slotSliderMoved(int value)
 {
     /* Set text for the top label */
@@ -1574,6 +1583,7 @@ void VCSlider::slotInputValueChanged(quint32 universe, quint32 channel, uchar va
             {
                 m_resetButton->setStyleSheet(QString("QToolButton{ background: red; }"));
                 m_isOverriding = true;
+                updateOverrideFeedback(true);
             }
 
             if (invertedAppearance())
