@@ -93,6 +93,19 @@ VCXYPadProperties::VCXYPadProperties(VCXYPad* xypad, Doc* doc)
     connect(m_panInputWidget, SIGNAL(inputValueChanged(quint32,quint32)),
             this, SLOT(slotPanInputValueChanged(quint32,quint32)));
 
+    m_panFineInputWidget = new InputSelectionWidget(m_doc, this);
+    m_panFineInputWidget->setTitle(tr("Pan Fine"));
+    m_panFineInputWidget->setKeyInputVisibility(false);
+    m_panFineInputWidget->setInputSource(m_xypad->inputSource(VCXYPad::panFineInputSourceId));
+    m_panFineInputWidget->setWidgetPage(m_xypad->page());
+    m_panFineInputWidget->emitOddValues(true);
+    m_panFineInputWidget->show();
+    m_extFineInputLayout->addWidget(m_panFineInputWidget);
+    connect(m_panFineInputWidget, SIGNAL(autoDetectToggled(bool)),
+            this, SLOT(slotPanFineAutoDetectToggled(bool)));
+    connect(m_panFineInputWidget, SIGNAL(inputValueChanged(quint32,quint32)),
+            this, SLOT(slotPanFineInputValueChanged(quint32,quint32)));
+
     m_tiltInputWidget = new InputSelectionWidget(m_doc, this);
     m_tiltInputWidget->setTitle(tr("Tilt / Vertical Axis"));
     m_tiltInputWidget->setKeyInputVisibility(false);
@@ -106,6 +119,19 @@ VCXYPadProperties::VCXYPadProperties(VCXYPad* xypad, Doc* doc)
     connect(m_tiltInputWidget, SIGNAL(inputValueChanged(quint32,quint32)),
             this, SLOT(slotTiltInputValueChanged(quint32,quint32)));
 
+    m_tiltFineInputWidget = new InputSelectionWidget(m_doc, this);
+    m_tiltFineInputWidget->setTitle(tr("Tilt Fine"));
+    m_tiltFineInputWidget->setKeyInputVisibility(false);
+    m_tiltFineInputWidget->setInputSource(m_xypad->inputSource(VCXYPad::tiltFineInputSourceId));
+    m_tiltFineInputWidget->setWidgetPage(m_xypad->page());
+    m_tiltFineInputWidget->emitOddValues(true);
+    m_tiltFineInputWidget->show();
+    m_extFineInputLayout->addWidget(m_tiltFineInputWidget);
+    connect(m_tiltFineInputWidget, SIGNAL(autoDetectToggled(bool)),
+            this, SLOT(slotTiltFineAutoDetectToggled(bool)));
+    connect(m_tiltFineInputWidget, SIGNAL(inputValueChanged(quint32,quint32)),
+            this, SLOT(slotTiltFineInputValueChanged(quint32,quint32)));
+
     m_widthInputWidget = new InputSelectionWidget(m_doc, this);
     m_widthInputWidget->setTitle(tr("Width"));
     m_widthInputWidget->setKeyInputVisibility(false);
@@ -432,10 +458,26 @@ void VCXYPadProperties::slotDMXRadioChecked()
  * Input page
  ****************************************************************************/
 
+void VCXYPadProperties::stopAutodetection(quint8 sourceId)
+{
+    if (sourceId != VCXYPad::panInputSourceId)
+        m_panInputWidget->stopAutoDetection();
+    if (sourceId != VCXYPad::panFineInputSourceId)
+        m_panFineInputWidget->stopAutoDetection();
+    if (sourceId != VCXYPad::tiltInputSourceId)
+        m_tiltInputWidget->stopAutoDetection();
+    if (sourceId != VCXYPad::tiltFineInputSourceId)
+        m_tiltFineInputWidget->stopAutoDetection();
+    if (sourceId != VCXYPad::widthInputSourceId)
+        m_widthInputWidget->stopAutoDetection();
+    if (sourceId != VCXYPad::heightInputSourceId)
+        m_heightInputWidget->stopAutoDetection();
+}
+
 void VCXYPadProperties::slotPanAutoDetectToggled(bool toggled)
 {
-    if (toggled == true && m_tiltInputWidget->isAutoDetecting())
-        m_tiltInputWidget->stopAutoDetection();
+    if (toggled == true)
+        stopAutodetection(VCXYPad::panInputSourceId);
 }
 
 void VCXYPadProperties::slotPanInputValueChanged(quint32 uni, quint32 ch)
@@ -446,10 +488,24 @@ void VCXYPadProperties::slotPanInputValueChanged(quint32 uni, quint32 ch)
                     QSharedPointer<QLCInputSource>(new QLCInputSource(uni, ch)));
 }
 
+void VCXYPadProperties::slotPanFineAutoDetectToggled(bool toggled)
+{
+    if (toggled == true)
+        stopAutodetection(VCXYPad::panFineInputSourceId);
+}
+
+void VCXYPadProperties::slotPanFineInputValueChanged(quint32 uni, quint32 ch)
+{
+    QSharedPointer<QLCInputSource> tmpSource = m_panFineInputWidget->inputSource();
+    if (tmpSource->universe() != uni || tmpSource->channel() != ch)
+        m_tiltFineInputWidget->setInputSource(
+            QSharedPointer<QLCInputSource>(new QLCInputSource(uni, ch)));
+}
+
 void VCXYPadProperties::slotTiltAutoDetectToggled(bool toggled)
 {
-    if (toggled == true && m_panInputWidget->isAutoDetecting())
-        m_panInputWidget->stopAutoDetection();
+    if (toggled == true)
+        stopAutodetection(VCXYPad::tiltInputSourceId);
 }
 
 void VCXYPadProperties::slotTiltInputValueChanged(quint32 uni, quint32 ch)
@@ -460,6 +516,20 @@ void VCXYPadProperties::slotTiltInputValueChanged(quint32 uni, quint32 ch)
                     QSharedPointer<QLCInputSource>(new QLCInputSource(uni, ch)));
 }
 
+void VCXYPadProperties::slotTiltFineAutoDetectToggled(bool toggled)
+{
+    if (toggled == true)
+        stopAutodetection(VCXYPad::tiltFineInputSourceId);
+}
+
+void VCXYPadProperties::slotTiltFineInputValueChanged(quint32 uni, quint32 ch)
+{
+    QSharedPointer<QLCInputSource> tmpSource = m_tiltFineInputWidget->inputSource();
+    if (tmpSource->universe() != uni || tmpSource->channel() != ch)
+        m_panFineInputWidget->setInputSource(
+            QSharedPointer<QLCInputSource>(new QLCInputSource(uni, ch)));
+}
+
 void VCXYPadProperties::writeDMX(MasterTimer *timer, QList<Universe *> universes)
 {
     Q_UNUSED(timer);
@@ -933,7 +1003,9 @@ void VCXYPadProperties::accept()
     m_xypad->clearFixtures();
     m_xypad->setCaption(m_nameEdit->text());
     m_xypad->setInputSource(m_panInputWidget->inputSource(), VCXYPad::panInputSourceId);
+    m_xypad->setInputSource(m_panFineInputWidget->inputSource(), VCXYPad::panFineInputSourceId);
     m_xypad->setInputSource(m_tiltInputWidget->inputSource(), VCXYPad::tiltInputSourceId);
+    m_xypad->setInputSource(m_tiltFineInputWidget->inputSource(), VCXYPad::tiltFineInputSourceId);
     m_xypad->setInputSource(m_widthInputWidget->inputSource(), VCXYPad::widthInputSourceId);
     m_xypad->setInputSource(m_heightInputWidget->inputSource(), VCXYPad::heightInputSourceId);
     if (m_YNormalRadio->isChecked())
